"use strict";
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
exports.__esModule = true;
var __testUtil__1 = require("../__testUtil__");
it("Supports keyframes", function () {
    var css = __testUtil__1.styled.test(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n    @keyframes fade-in {\n      0% {\n        opacity: 0;\n      }\n      100% {\n        opacity: 1;\n      }\n    }\n  "], ["\n    @keyframes fade-in {\n      0% {\n        opacity: 0;\n      }\n      100% {\n        opacity: 1;\n      }\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    const keyframes = {\n      'fade-in': [{\n        'time': 0,\n        'style': {\n          opacity: 0\n        }\n      }, {\n        'time': 1,\n        'style': {\n          opacity: 1\n        }\n      }]\n    };\n    const Example = React.forwardRef((props, ref) => {\n      return <Element {...props} ref={ref} />;\n    });\"\n  ");
});
it("Supports animations", function () {
    var css = __testUtil__1.styled.test(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n    animation: fade-in 1s;\n\n    @keyframes fade-in {\n      0% {\n        opacity: 0;\n      }\n      100% {\n        opacity: 1;\n      }\n    }\n  "], ["\n    animation: fade-in 1s;\n\n    @keyframes fade-in {\n      0% {\n        opacity: 0;\n      }\n      100% {\n        opacity: 1;\n      }\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useAnimation from 'cssta/runtime/useAnimation';\n    const keyframes = {\n      'fade-in': [{\n        'time': 0,\n        'style': {\n          opacity: 0\n        }\n      }, {\n        'time': 1,\n        'style': {\n          opacity: 1\n        }\n      }]\n    };\n    const animation = {\n      'delay': 0,\n      'duration': 1000,\n      'iterations': 1,\n      'name': 'fade-in',\n      'timingFunction': 'ease'\n    };\n    const Example = React.forwardRef((props, ref) => {\n      let style = props.style;\n      style = useAnimation(keyframes, animation, style);\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports conditional animations", function () {
    var css = __testUtil__1.styled.test(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n    animation: fade-in 1s;\n\n    &[@slow] {\n      animation: fade-in 5s;\n    }\n\n    @keyframes fade-in {\n      0% {\n        opacity: 0;\n      }\n      100% {\n        opacity: 1;\n      }\n    }\n  "], ["\n    animation: fade-in 1s;\n\n    &[@slow] {\n      animation: fade-in 5s;\n    }\n\n    @keyframes fade-in {\n      0% {\n        opacity: 0;\n      }\n      100% {\n        opacity: 1;\n      }\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import flattenAnimation from 'cssta/runtime/flattenAnimation';\n    import useAnimation from 'cssta/runtime/useAnimation';\n    const keyframes = {\n      'fade-in': [{\n        'time': 0,\n        'style': {\n          opacity: 0\n        }\n      }, {\n        'time': 1,\n        'style': {\n          opacity: 1\n        }\n      }]\n    };\n    const Example = React.forwardRef(({\n      slow,\n      ...props\n    }, ref) => {\n      let style = props.style;\n      const animation = flattenAnimation([{\n        '_': 'fade-in 1s'\n      }, slow === true ? {\n        '_': 'fade-in 5s'\n      } : null]);\n      style = useAnimation(keyframes, animation, style);\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
var templateObject_1, templateObject_2, templateObject_3;
