"use strict";
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
exports.__esModule = true;
var __testUtil__1 = require("../__testUtil__");
it("Supports basic styles", function () {
    var css = __testUtil__1.styled.test(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n    color: green;\n  "], ["\n    color: green;\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    const styles0 = {\n      color: 'green'\n    };\n    const Example = React.forwardRef((props, ref) => {\n      const style = props.style != null ? [styles0, props.style] : styles0;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports basic multiple implicitly-scoped declarations", function () {
    var css = __testUtil__1.styled.test(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n    color: green;\n    width: 100px;\n  "], ["\n    color: green;\n    width: 100px;\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    const styles0 = {\n      color: 'green',\n      width: 100\n    };\n    const Example = React.forwardRef((props, ref) => {\n      const style = props.style != null ? [styles0, props.style] : styles0;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports boolean conditional styles", function () {
    var css = __testUtil__1.styled.test(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n    color: green;\n\n    &[@test] {\n      color: blue;\n    }\n  "], ["\n    color: green;\n\n    &[@test] {\n      color: blue;\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    const styles0 = {\n      color: 'green'\n    };\n    const styles1 = {\n      color: 'blue'\n    };\n    const Example = React.forwardRef(({\n      test,\n      ...props\n    }, ref) => {\n      const baseStyle = test === true ? styles1 : styles0;\n      const style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports string conditional styles", function () {
    var css = __testUtil__1.styled.test(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n    width: 100px;\n\n    &[@size=\"small\"] {\n      width: 80px;\n    }\n\n    &[@size=\"large\"] {\n      width: 120px;\n    }\n  "], ["\n    width: 100px;\n\n    &[@size=\"small\"] {\n      width: 80px;\n    }\n\n    &[@size=\"large\"] {\n      width: 120px;\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    const styles0 = {\n      width: 100\n    };\n    const styles1 = {\n      width: 80\n    };\n    const styles2 = {\n      width: 120\n    };\n    const Example = React.forwardRef(({\n      size,\n      ...props\n    }, ref) => {\n      const baseStyle = size === 'large' ? styles2 : size === 'small' ? styles1 : styles0;\n      const style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Optimizes a single conditional style", function () {
    var css = __testUtil__1.styled.test(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n    color: green;\n\n    &[@test] {\n      margin: 10px;\n    }\n  "], ["\n    color: green;\n\n    &[@test] {\n      margin: 10px;\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    const styles0 = {\n      color: 'green'\n    };\n    const styles1 = {\n      color: 'green',\n      marginTop: 10,\n      marginRight: 10,\n      marginBottom: 10,\n      marginLeft: 10\n    };\n    const Example = React.forwardRef(({\n      test,\n      ...props\n    }, ref) => {\n      const baseStyle = test === true ? styles1 : styles0;\n      const style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5;
