"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var babel = __importStar(require("@babel/core"));
var generator_1 = __importDefault(require("@babel/generator"));
var environment_1 = __importDefault(require("../environment"));
var buildCondition_1 = __importDefault(require("../buildCondition"));
var t = babel.types;
var run = function (inputSelector, mediaQuery) {
    var selector = inputSelector.replace(/@/g, "cssta|");
    var ast = babel.parse("const selector = () => {}");
    babel.traverse(ast, {
        ArrowFunctionExpression: function (path) {
            var body = path.get("body");
            var environment = environment_1["default"](babel, body);
            var node = buildCondition_1["default"](babel, { selector: selector, mediaQuery: mediaQuery }, environment);
            body.pushContainer("body", t.returnStatement(node));
        }
    });
    var code = generator_1["default"](ast).code;
    return code.replace(/"/g, "'");
};
it("Creates a boolean selector", function () {
    var code = run("&[@test]");
    expect(code).toMatchInlineSnapshot("\n    \"const selector = () => {\n      return test === true;\n    };\"\n  ");
});
it("Creates a string selector", function () {
    var code = run('&[@test="test"]');
    expect(code).toMatchInlineSnapshot("\n    \"const selector = () => {\n      return test === 'test';\n    };\"\n  ");
});
it("Combines two selectors", function () {
    var code = run('&[@test][@other="test"]');
    expect(code).toMatchInlineSnapshot("\n    \"const selector = () => {\n      return test === true && other === 'test';\n    };\"\n  ");
});
it("Combines three selectors", function () {
    var code = run('&[@test][@other="test"][@another="testing"]');
    expect(code).toMatchInlineSnapshot("\n    \"const selector = () => {\n      return test === true && other === 'test' && another === 'testing';\n    };\"\n  ");
});
it("Handles :not selectors for booleans", function () {
    var code = run("&:not([@test])");
    expect(code).toMatchInlineSnapshot("\n    \"const selector = () => {\n      return !(test === true);\n    };\"\n  ");
});
it("Handles :not selectors for strings", function () {
    var code = run('&:not([@test="test"])');
    expect(code).toMatchInlineSnapshot("\n    \"const selector = () => {\n      return !(test === 'test');\n    };\"\n  ");
});
it("Handles :not with combined selectors", function () {
    var code = run('&:not([@test][@other="test"])');
    expect(code).toMatchInlineSnapshot("\n    \"const selector = () => {\n      return !(test === true && other === 'test');\n    };\"\n  ");
});
it("Handles combined regular and :not selectors", function () {
    var code = run('&[@test]:not([@other="test"])');
    expect(code).toMatchInlineSnapshot("\n    \"const selector = () => {\n      return test === true && !(other === 'test');\n    };\"\n  ");
});
it("Handles :matches selectors", function () {
    var code = run('&:matches([@test="a"], [@test="b"], [@test="c"])');
    expect(code).toMatchInlineSnapshot("\n    \"const selector = () => {\n      return test === 'a' || test === 'b' || test === 'c';\n    };\"\n  ");
});
it("Handles combined regular and :matches selectors", function () {
    var code = run('&[@test]:matches([@other="a"], [@other="b"], [@other="c"])');
    expect(code).toMatchInlineSnapshot("\n    \"const selector = () => {\n      return test === true && (other === 'a' || other === 'b' || other === 'c');\n    };\"\n  ");
});
it("Throws on attribute selectors", function () {
    expect(function () {
        run("&[prop]");
    }).toThrow();
});
it("Throws on invalid :pseudo selectors", function () {
    expect(function () {
        run("&:pseudo()");
    }).toThrow();
});
it("Handles multiple selectors", function () {
    var code = run('&[@test], &[@other="c"]');
    expect(code).toMatchInlineSnapshot("\n    \"const selector = () => {\n      return test === true || other === 'c';\n    };\"\n  ");
});
it("Handles sceen media queries", function () {
    expect(run("&", "(min-width: 500px)")).toMatchInlineSnapshot("\n    \"import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n\n    const selector = () => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      return windowWidth >= 500;\n    };\"\n  ");
    expect(run("&", "(max-width: 500px)")).toMatchInlineSnapshot("\n    \"import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n\n    const selector = () => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      return windowWidth <= 500;\n    };\"\n  ");
    expect(run("&", "(width: 500px)")).toMatchInlineSnapshot("\n    \"import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n\n    const selector = () => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      return windowWidth === 500;\n    };\"\n  ");
    expect(run("&", "(min-height: 500px)")).toMatchInlineSnapshot("\n    \"import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n\n    const selector = () => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      return windowHeight >= 500;\n    };\"\n  ");
    expect(run("&", "(max-height: 500px)")).toMatchInlineSnapshot("\n    \"import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n\n    const selector = () => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      return windowHeight <= 500;\n    };\"\n  ");
    expect(run("&", "(height: 500px)")).toMatchInlineSnapshot("\n    \"import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n\n    const selector = () => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      return windowHeight === 500;\n    };\"\n  ");
    expect(run("&", "(min-aspect-ratio: 16/9)")).toMatchInlineSnapshot("\n    \"import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n\n    const selector = () => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      return 16 / 9 <= windowWidth / windowHeight;\n    };\"\n  ");
    expect(run("&", "(max-aspect-ratio: 16/9)")).toMatchInlineSnapshot("\n    \"import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n\n    const selector = () => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      return 16 / 9 >= windowWidth / windowHeight;\n    };\"\n  ");
    expect(run("&", "(aspect-ratio: 16/9)")).toMatchInlineSnapshot("\n    \"import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n\n    const selector = () => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      return 16 / 9 === windowWidth / windowHeight;\n    };\"\n  ");
    expect(run("&", "(orientation: landscape)")).toMatchInlineSnapshot("\n    \"import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n\n    const selector = () => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      return windowWidth > windowHeight;\n    };\"\n  ");
    expect(run("&", "(orientation: portrait)")).toMatchInlineSnapshot("\n    \"import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n\n    const selector = () => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      return windowWidth < windowHeight;\n    };\"\n  ");
});
it("Handles color scheme media queries", function () {
    expect(run("&", "(prefers-color-scheme: dark)")).toMatchInlineSnapshot("\n    \"import { useColorScheme } from 'react-native';\n\n    const selector = () => {\n      const colorScheme = useColorScheme();\n      return colorScheme === 'dark';\n    };\"\n  ");
    expect(run("&", "(prefers-color-scheme: light)")).toMatchInlineSnapshot("\n    \"import { useColorScheme } from 'react-native';\n\n    const selector = () => {\n      const colorScheme = useColorScheme();\n      return colorScheme === 'light';\n    };\"\n  ");
});
it("Handles platform media queries", function () {
    expect(run("&", "(platform: ios)")).toMatchInlineSnapshot("\n    \"import { Platform } from 'react-native';\n\n    const selector = () => {\n      return Platform.OS === 'ios';\n    };\"\n  ");
    expect(run("&", "(platform: android)")).toMatchInlineSnapshot("\n    \"import { Platform } from 'react-native';\n\n    const selector = () => {\n      return Platform.OS === 'android';\n    };\"\n  ");
});
it("Throws when cannot parse media query", function () {
    expect(function () {
        run("&", "(not-a-query: no-it-isn't)");
    }).toThrow();
});
it("Handles intersection media queries", function () {
    var code = run("&", "(min-width: 500px) and (prefers-color-scheme: dark)");
    expect(code).toMatchInlineSnapshot("\n    \"import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n    import { useColorScheme } from 'react-native';\n\n    const selector = () => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      const colorScheme = useColorScheme();\n      return windowWidth >= 500 && colorScheme === 'dark';\n    };\"\n  ");
});
it("Handles union media queries", function () {
    var code = run("&", "(min-width: 500px), (prefers-color-scheme: dark)");
    expect(code).toMatchInlineSnapshot("\n    \"import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n    import { useColorScheme } from 'react-native';\n\n    const selector = () => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      const colorScheme = useColorScheme();\n      return windowWidth >= 500 || colorScheme === 'dark';\n    };\"\n  ");
});
it("Handles selectors with media queries", function () {
    var code = run("&[@test]", "(min-width: 500px)");
    expect(code).toMatchInlineSnapshot("\n    \"import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n\n    const selector = () => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      return test === true && windowWidth >= 500;\n    };\"\n  ");
});
