"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var babel = __importStar(require("@babel/core"));
var generator_1 = __importDefault(require("@babel/generator"));
var buildElement_1 = __importDefault(require("../buildElement"));
it("Works with substititions", function () {
    var ast = babel.parse("\n    const Test = styled(Button)`\n      color: ${red};\n      margin: ${small};\n      top: ${small};\n      opacity: ${half};\n    `;\n  ");
    babel.traverse(ast, {
        TaggedTemplateExpression: function (path) {
            var _a = path.node, tag = _a.tag, body = _a.quasi;
            var element = tag.arguments[0];
            buildElement_1["default"](babel, path, element, body, { jsx: true });
        }
    });
    var code = generator_1["default"](ast).code;
    expect(code).toMatchInlineSnapshot("\n    \"import React from \\\"react\\\";\n    import { transformStyleTuples } from \\\"cssta/runtime/cssUtil\\\";\n    import { transformRawValue } from \\\"cssta/runtime/cssUtil\\\";\n    const styles0 = Object.assign({\n      color: String(red).trim()\n    }, transformStyleTuples([[\\\"margin\\\", `${small}`]]), {\n      top: transformRawValue(small),\n      opacity: Number(half)\n    });\n    const Test = React.forwardRef((props, ref) => {\n      const style = props.style != null ? [styles0, props.style] : styles0;\n      return <Button {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Works with substititions and simple viewport units", function () {
    var ast = babel.parse("\n    const Test = styled(Button)`\n      color: ${red};\n      top: 10vw;\n      opacity: ${something};\n    `;\n  ");
    babel.traverse(ast, {
        TaggedTemplateExpression: function (path) {
            var _a = path.node, tag = _a.tag, body = _a.quasi;
            var element = tag.arguments[0];
            buildElement_1["default"](babel, path, element, body, { jsx: true });
        }
    });
    var code = generator_1["default"](ast).code;
    expect(code).toMatchInlineSnapshot("\n    \"import React from \\\"react\\\";\n    import useWindowDimensions from \\\"cssta/runtime/useWindowDimensions\\\";\n    const Test = React.forwardRef((props, ref) => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      const baseStyle = {\n        color: String(red).trim(),\n        top: Number(windowWidth * 0.1),\n        opacity: Number(something)\n      };\n      const style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      return <Button {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
