"use strict";
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
exports.__esModule = true;
var __testUtil__1 = require("../__testUtil__");
it("Supports media queries", function () {
    var css = __testUtil__1.styled.test(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n    color: green;\n\n    @media (min-width: 500px) {\n      color: red;\n    }\n  "], ["\n    color: green;\n\n    @media (min-width: 500px) {\n      color: red;\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n    const styles0 = {\n      color: 'green'\n    };\n    const styles1 = {\n      color: 'red'\n    };\n    const Example = React.forwardRef((props, ref) => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      const baseStyle = windowWidth >= 500 ? styles1 : styles0;\n      const style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports media queries with conditions", function () {
    var css = __testUtil__1.styled.test(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n    color: green;\n\n    @media (min-width: 500px) {\n      color: red;\n\n      &[@large] {\n        width: 500px;\n      }\n    }\n  "], ["\n    color: green;\n\n    @media (min-width: 500px) {\n      color: red;\n\n      &[@large] {\n        width: 500px;\n      }\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n    const styles0 = {\n      color: 'green'\n    };\n    const styles1 = {\n      color: 'red'\n    };\n    const styles2 = {\n      width: 500\n    };\n    const Example = React.forwardRef(({\n      large,\n      ...props\n    }, ref) => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      const style = [windowWidth >= 500 ? styles1 : styles0, large === true && windowWidth >= 500 ? styles2 : null, props.style];\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports platform media queries", function () {
    var css = __testUtil__1.styled.test(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n    color: green;\n\n    @media (platform: ios) {\n      color: red;\n    }\n  "], ["\n    color: green;\n\n    @media (platform: ios) {\n      color: red;\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import { Platform } from 'react-native';\n    const styles0 = {\n      color: 'green'\n    };\n    const styles1 = {\n      color: 'red'\n    };\n    const Example = React.forwardRef((props, ref) => {\n      const baseStyle = Platform.OS === 'ios' ? styles1 : styles0;\n      const style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports color scheme media queries", function () {
    var css = __testUtil__1.styled.test(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n    color: green;\n\n    @media (prefers-color-scheme: dark) {\n      color: red;\n    }\n  "], ["\n    color: green;\n\n    @media (prefers-color-scheme: dark) {\n      color: red;\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import { useColorScheme } from 'react-native';\n    const styles0 = {\n      color: 'green'\n    };\n    const styles1 = {\n      color: 'red'\n    };\n    const Example = React.forwardRef((props, ref) => {\n      const colorScheme = useColorScheme();\n      const baseStyle = colorScheme === 'dark' ? styles1 : styles0;\n      const style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports combined media queries", function () {
    var css = __testUtil__1.styled.test(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n    color: green;\n\n    @media (platform: ios) and (min-width: 500) {\n      color: red;\n    }\n  "], ["\n    color: green;\n\n    @media (platform: ios) and (min-width: 500) {\n      color: red;\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import { Platform } from 'react-native';\n    import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n    const styles0 = {\n      color: 'green'\n    };\n    const styles1 = {\n      color: 'red'\n    };\n    const Example = React.forwardRef((props, ref) => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      const baseStyle = Platform.OS === 'ios' && windowWidth >= 500 ? styles1 : styles0;\n      const style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5;
