"use strict";
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
exports.__esModule = true;
var __testUtil__1 = require("../__testUtil__");
it("Supports exported variables in media queries", function () {
    var css = __testUtil__1.styled.test(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n    --width: 100px;\n\n    @media (min-width: 500px) {\n      --width: 200px;\n    }\n  "], ["\n    --width: 100px;\n\n    @media (min-width: 500px) {\n      --width: 200px;\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n    import useCustomProperties from 'cssta/runtime/useCustomProperties';\n    import VariablesContext from 'cssta/runtime/VariablesContext';\n    const Example = React.forwardRef((props, ref) => {\n      const exportedCustomProperties = {};\n      exportedCustomProperties['width'] = '100px';\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n\n      if (windowWidth >= 500) {\n        exportedCustomProperties['width'] = '200px';\n      }\n\n      const customProperties = useCustomProperties(exportedCustomProperties);\n      return <VariablesContext.Provider value={customProperties}><Element {...props} ref={ref} /></VariablesContext.Provider>;\n    });\"\n  ");
});
it("Supports transitions vith custom properties", function () {
    var css = __testUtil__1.styled.test(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n    color: red;\n    transition: color var(--time);\n\n    &[@active] {\n      color: green;\n    }\n  "], ["\n    color: red;\n    transition: color var(--time);\n\n    &[@active] {\n      color: green;\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useCustomProperties from 'cssta/runtime/useCustomProperties';\n    import useCustomPropertyShorthandParts from 'cssta/runtime/useCustomPropertyShorthandParts';\n    import flattenTransition from 'cssta/runtime/flattenTransition';\n    import useTransition from 'cssta/runtime/useTransition';\n    const styles0 = {\n      color: 'red'\n    };\n    const styles1 = {\n      color: 'green'\n    };\n    const Example = React.forwardRef(({\n      active,\n      ...props\n    }, ref) => {\n      const customProperties = useCustomProperties(null);\n      const baseStyle = active === true ? styles1 : styles0;\n      let style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      const unresolvedTransitionParts = [{\n        '_': 'color var(--time)'\n      }];\n      const transitionParts = useCustomPropertyShorthandParts(unresolvedTransitionParts, customProperties);\n      const transition = flattenTransition(transitionParts);\n      style = useTransition(transition, style);\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports conditional transitions with custom properties", function () {
    var css = __testUtil__1.styled.test(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n    color: red;\n    transition: color var(--time);\n\n    &[@fast] {\n      transition-duration: var(--time-fast);\n    }\n\n    &[@slow] {\n      transition-duration: var(--time-slow);\n    }\n  "], ["\n    color: red;\n    transition: color var(--time);\n\n    &[@fast] {\n      transition-duration: var(--time-fast);\n    }\n\n    &[@slow] {\n      transition-duration: var(--time-slow);\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useCustomProperties from 'cssta/runtime/useCustomProperties';\n    import useCustomPropertyShorthandParts from 'cssta/runtime/useCustomPropertyShorthandParts';\n    import flattenTransition from 'cssta/runtime/flattenTransition';\n    import useTransition from 'cssta/runtime/useTransition';\n    const styles0 = {\n      color: 'red'\n    };\n    const Example = React.forwardRef(({\n      fast,\n      slow,\n      ...props\n    }, ref) => {\n      const customProperties = useCustomProperties(null);\n      let style = props.style != null ? [styles0, props.style] : styles0;\n      const unresolvedTransitionParts = [{\n        '_': 'color var(--time)'\n      }, fast === true ? {\n        'duration': 'var(--time-fast)'\n      } : null, slow === true ? {\n        'duration': 'var(--time-slow)'\n      } : null];\n      const transitionParts = useCustomPropertyShorthandParts(unresolvedTransitionParts, customProperties);\n      const transition = flattenTransition(transitionParts);\n      style = useTransition(transition, style);\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports animations with custom properties", function () {
    var css = __testUtil__1.styled.test(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n    animation: fade-in var(--time);\n\n    @keyframes fade-in {\n      0% {\n        opacity: 0;\n      }\n      100% {\n        opacity: 1;\n      }\n    }\n  "], ["\n    animation: fade-in var(--time);\n\n    @keyframes fade-in {\n      0% {\n        opacity: 0;\n      }\n      100% {\n        opacity: 1;\n      }\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useCustomProperties from 'cssta/runtime/useCustomProperties';\n    import useCustomPropertyShorthandParts from 'cssta/runtime/useCustomPropertyShorthandParts';\n    import flattenAnimation from 'cssta/runtime/flattenAnimation';\n    import useAnimation from 'cssta/runtime/useAnimation';\n    const keyframes = {\n      'fade-in': [{\n        'time': 0,\n        'style': {\n          opacity: 0\n        }\n      }, {\n        'time': 1,\n        'style': {\n          opacity: 1\n        }\n      }]\n    };\n    const Example = React.forwardRef((props, ref) => {\n      const customProperties = useCustomProperties(null);\n      let style = props.style;\n      const unresolvedAnimationParts = [{\n        '_': 'fade-in var(--time)'\n      }];\n      const animationParts = useCustomPropertyShorthandParts(unresolvedAnimationParts, customProperties);\n      const animation = flattenAnimation(animationParts);\n      style = useAnimation(keyframes, animation, style);\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports conditional animations with custom properties", function () {
    var css = __testUtil__1.styled.test(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n    animation: fade-in var(--time);\n\n    &[@slow] {\n      animation: fade-in var(--time-slow);\n    }\n\n    @keyframes fade-in {\n      0% {\n        opacity: 0;\n      }\n      100% {\n        opacity: 1;\n      }\n    }\n  "], ["\n    animation: fade-in var(--time);\n\n    &[@slow] {\n      animation: fade-in var(--time-slow);\n    }\n\n    @keyframes fade-in {\n      0% {\n        opacity: 0;\n      }\n      100% {\n        opacity: 1;\n      }\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useCustomProperties from 'cssta/runtime/useCustomProperties';\n    import useCustomPropertyShorthandParts from 'cssta/runtime/useCustomPropertyShorthandParts';\n    import flattenAnimation from 'cssta/runtime/flattenAnimation';\n    import useAnimation from 'cssta/runtime/useAnimation';\n    const keyframes = {\n      'fade-in': [{\n        'time': 0,\n        'style': {\n          opacity: 0\n        }\n      }, {\n        'time': 1,\n        'style': {\n          opacity: 1\n        }\n      }]\n    };\n    const Example = React.forwardRef(({\n      slow,\n      ...props\n    }, ref) => {\n      const customProperties = useCustomProperties(null);\n      let style = props.style;\n      const unresolvedAnimationParts = [{\n        '_': 'fade-in var(--time)'\n      }, slow === true ? {\n        '_': 'fade-in var(--time-slow)'\n      } : null];\n      const animationParts = useCustomPropertyShorthandParts(unresolvedAnimationParts, customProperties);\n      const animation = flattenAnimation(animationParts);\n      style = useAnimation(keyframes, animation, style);\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports transitions with animations", function () {
    var css = __testUtil__1.styled.test(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n    animation: fade-in 1s;\n    transition: color 1s;\n    color: black;\n\n    &[@inverted] {\n      color: white;\n    }\n\n    @keyframes fade-in {\n      0% {\n        opacity: 0;\n      }\n      100% {\n        opacity: 1;\n      }\n    }\n  "], ["\n    animation: fade-in 1s;\n    transition: color 1s;\n    color: black;\n\n    &[@inverted] {\n      color: white;\n    }\n\n    @keyframes fade-in {\n      0% {\n        opacity: 0;\n      }\n      100% {\n        opacity: 1;\n      }\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useTransition from 'cssta/runtime/useTransition';\n    import useAnimation from 'cssta/runtime/useAnimation';\n    const styles0 = {\n      color: 'black'\n    };\n    const styles1 = {\n      color: 'white'\n    };\n    const transition = [{\n      'property': 'color',\n      'timingFunction': 'ease',\n      'delay': 0,\n      'duration': 1000\n    }];\n    const keyframes = {\n      'fade-in': [{\n        'time': 0,\n        'style': {\n          opacity: 0\n        }\n      }, {\n        'time': 1,\n        'style': {\n          opacity: 1\n        }\n      }]\n    };\n    const animation = {\n      'delay': 0,\n      'duration': 1000,\n      'iterations': 1,\n      'name': 'fade-in',\n      'timingFunction': 'ease'\n    };\n    const Example = React.forwardRef(({\n      inverted,\n      ...props\n    }, ref) => {\n      const baseStyle = inverted === true ? styles1 : styles0;\n      let style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      style = useTransition(transition, style);\n      style = useAnimation(keyframes, animation, style);\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports viewport units in shorthands with custom properties", function () {
    var css = __testUtil__1.styled.test(templateObject_7 || (templateObject_7 = __makeTemplateObject(["\n    margin: 10vw var(--whyDoIDoThisToMyself);\n  "], ["\n    margin: 10vw var(--whyDoIDoThisToMyself);\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useCustomProperties from 'cssta/runtime/useCustomProperties';\n    import useViewportStyleTuples from 'cssta/runtime/useViewportStyleTuples';\n    import useCustomPropertyStyles from 'cssta/runtime/useCustomPropertyStyles';\n    const unresolvedStyleTuples0 = [['margin', '10vw var(--whyDoIDoThisToMyself)']];\n    const Example = React.forwardRef((props, ref) => {\n      const customProperties = useCustomProperties(null);\n      const unresolvedStyleTuples1 = useViewportStyleTuples(unresolvedStyleTuples0);\n      const styles = useCustomPropertyStyles(unresolvedStyleTuples1, customProperties);\n      const style = props.style != null ? [styles, props.style] : styles;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7;
