"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var babel = __importStar(require("@babel/core"));
var generator_1 = __importDefault(require("@babel/generator"));
var buildElement_1 = __importDefault(require("../buildElement"));
it("Works with mixins", function () {
    var ast = babel.parse("\n    const Test = styled(Button)`\n      @include ${useStyles};\n    `;\n  ");
    babel.traverse(ast, {
        TaggedTemplateExpression: function (path) {
            var _a = path.node, tag = _a.tag, body = _a.quasi;
            var element = tag.arguments[0];
            buildElement_1["default"](babel, path, element, body, { jsx: true });
        }
    });
    var code = generator_1["default"](ast).code;
    expect(code).toMatchInlineSnapshot("\n    \"import React from \\\"react\\\";\n    const Test = React.forwardRef((props, ref) => {\n      const mixinInclude0 = useStyles();\n      const style = props.style != null ? [mixinInclude0, props.style] : mixinInclude0;\n      return <Button {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Works with conditional mixins", function () {
    var ast = babel.parse("\n    const Test = styled(Button)`\n      &[@someTest] {\n        @include ${useStyles};\n      }\n    `;\n  ");
    babel.traverse(ast, {
        TaggedTemplateExpression: function (path) {
            var _a = path.node, tag = _a.tag, body = _a.quasi;
            var element = tag.arguments[0];
            buildElement_1["default"](babel, path, element, body, { jsx: true });
        }
    });
    var code = generator_1["default"](ast).code;
    expect(code).toMatchInlineSnapshot("\n    \"import React from \\\"react\\\";\n    const Test = React.forwardRef(({\n      someTest,\n      ...props\n    }, ref) => {\n      const mixinInclude0 = useStyles();\n      const baseStyle = someTest === true ? mixinInclude0 : null;\n      const style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      return <Button {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Works with multiple mixins", function () {
    var ast = babel.parse("\n    const Test = styled(Button)`\n      @include ${useStyles};\n\n      &[@someTest] {\n        @include ${useOtherStyles};\n      }\n    `;\n  ");
    babel.traverse(ast, {
        TaggedTemplateExpression: function (path) {
            var _a = path.node, tag = _a.tag, body = _a.quasi;
            var element = tag.arguments[0];
            buildElement_1["default"](babel, path, element, body, { jsx: true });
        }
    });
    var code = generator_1["default"](ast).code;
    expect(code).toMatchInlineSnapshot("\n    \"import React from \\\"react\\\";\n    const Test = React.forwardRef(({\n      someTest,\n      ...props\n    }, ref) => {\n      const mixinInclude0 = useStyles();\n      const mixinInclude1 = useOtherStyles();\n      const style = [mixinInclude0, someTest === true ? mixinInclude1 : null, props.style];\n      return <Button {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Gives sensible error message when using mixins incorrectly", function () {
    var ast = babel.parse("\n    const Test = styled(Button)`\n      @include notASubstitution\n    `;\n  ");
    expect(function () {
        babel.traverse(ast, {
            TaggedTemplateExpression: function (path) {
                var _a = path.node, tag = _a.tag, body = _a.quasi;
                var element = tag.arguments[0];
                buildElement_1["default"](babel, path, element, body, { jsx: true });
            }
        });
    }).toThrow("Mixins should use interpolation (e.g. @include ${useStyles})");
});
