"use strict";
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var babel = __importStar(require("@babel/core"));
var generator_1 = __importDefault(require("@babel/generator"));
var __testUtil__1 = require("../__testUtil__");
var buildMixin_1 = __importDefault(require("../buildMixin"));
var t = babel.types;
var build = function (css, options) {
    if (options === void 0) { options = {}; }
    var ast = babel.parse("const Example = 'replaceMe'");
    babel.traverse(ast, {
        StringLiteral: function (path) {
            if (path.node.value === "replaceMe") {
                buildMixin_1["default"](babel, path, t.templateLiteral([t.templateElement({ raw: css, cooked: css })], []), options);
            }
        }
    });
    var code = generator_1["default"](ast).code;
    return code.replace(/"/g, "'");
};
it("Supports mixins", function () {
    var css = __testUtil__1.styled.test(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n    color: red;\n  "], ["\n    color: red;\n  "])));
    var code = build(css);
    expect(code).toMatchInlineSnapshot("\n    \"const styles0 = {\n      color: 'red'\n    };\n\n    const Example = () => {\n      const style = styles0;\n      return style;\n    };\"\n  ");
});
it("Supports mixins with custom properties", function () {
    var css = __testUtil__1.styled.test(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n    color: var(--red);\n  "], ["\n    color: var(--red);\n  "])));
    var code = build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import useCustomProperties from 'cssta/runtime/useCustomProperties';\n    import useCustomPropertyStyles from 'cssta/runtime/useCustomPropertyStyles';\n    const unresolvedStyleTuples0 = [['color', 'var(--red)']];\n\n    const Example = () => {\n      const customProperties = useCustomProperties(null);\n      const styles = useCustomPropertyStyles(unresolvedStyleTuples0, customProperties);\n      const style = styles;\n      return style;\n    };\"\n  ");
});
it("Supports mixins with simple viewport units", function () {
    var css = __testUtil__1.styled.test(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n    width: 20vw;\n  "], ["\n    width: 20vw;\n  "])));
    var code = build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n\n    const Example = () => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      const baseStyle = {\n        width: Number(windowWidth * 0.2)\n      };\n      const style = baseStyle;\n      return style;\n    };\"\n  ");
});
it("Supports mixins with shorthand viewport units", function () {
    var css = __testUtil__1.styled.test(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n    margin: 20vw;\n  "], ["\n    margin: 20vw;\n  "])));
    var code = build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import useViewportStyle from 'cssta/runtime/useViewportStyle';\n    const unresolvedStyleTuples0 = [['margin', '20vw']];\n\n    const Example = () => {\n      const styles0 = useViewportStyle(unresolvedStyleTuples0);\n      const style = styles0;\n      return style;\n    };\"\n  ");
});
it("Throws on unsupported features", function () {
    expect(function () {
        build(__testUtil__1.styled.test(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n      --exportedVar: something;\n    "], ["\n      --exportedVar: something;\n    "]))));
    }).toThrow();
    expect(function () {
        build(__testUtil__1.styled.test(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n      transition: all 1s;\n    "], ["\n      transition: all 1s;\n    "]))));
    }).toThrow();
    expect(function () {
        build(__testUtil__1.styled.test(templateObject_7 || (templateObject_7 = __makeTemplateObject(["\n      animation: 1s someKeyframe;\n    "], ["\n      animation: 1s someKeyframe;\n    "]))));
    }).toThrow();
    expect(function () {
        build(__testUtil__1.styled.test(templateObject_8 || (templateObject_8 = __makeTemplateObject(["\n      @keyframes someTest {\n        0% {\n          opacity: 0;\n        }\n        100% {\n          opacity: 1;\n        }\n      }\n    "], ["\n      @keyframes someTest {\n        0% {\n          opacity: 0;\n        }\n        100% {\n          opacity: 1;\n        }\n      }\n    "]))));
    }).toThrow();
});
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7, templateObject_8;
