"use strict";
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
exports.__esModule = true;
var __testUtil__1 = require("../__testUtil__");
it("Supports imported variables", function () {
    var css = __testUtil__1.styled.test(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n    width: var(--width);\n  "], ["\n    width: var(--width);\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useCustomProperties from 'cssta/runtime/useCustomProperties';\n    import useCustomPropertyStyles from 'cssta/runtime/useCustomPropertyStyles';\n    const unresolvedStyleTuples0 = [['width', 'var(--width)']];\n    const Example = React.forwardRef((props, ref) => {\n      const customProperties = useCustomProperties(null);\n      const styles = useCustomPropertyStyles(unresolvedStyleTuples0, customProperties);\n      const style = props.style != null ? [styles, props.style] : styles;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports exported variables", function () {
    var css = __testUtil__1.styled.test(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n    --width: 100px;\n  "], ["\n    --width: 100px;\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useCustomProperties from 'cssta/runtime/useCustomProperties';\n    import VariablesContext from 'cssta/runtime/VariablesContext';\n    const exportedCustomProperties = {\n      'width': '100px'\n    };\n    const Example = React.forwardRef((props, ref) => {\n      const customProperties = useCustomProperties(exportedCustomProperties);\n      return <VariablesContext.Provider value={customProperties}><Element {...props} ref={ref} /></VariablesContext.Provider>;\n    });\"\n  ");
});
it("Supports imported and exported variables", function () {
    var css = __testUtil__1.styled.test(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n    --width: var(--height);\n  "], ["\n    --width: var(--height);\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useCustomProperties from 'cssta/runtime/useCustomProperties';\n    import VariablesContext from 'cssta/runtime/VariablesContext';\n    const exportedCustomProperties = {\n      'width': 'var(--height)'\n    };\n    const Example = React.forwardRef((props, ref) => {\n      const customProperties = useCustomProperties(exportedCustomProperties);\n      return <VariablesContext.Provider value={customProperties}><Element {...props} ref={ref} /></VariablesContext.Provider>;\n    });\"\n  ");
});
it("Supports conditional exported variables", function () {
    var css = __testUtil__1.styled.test(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n    --width: 100px;\n\n    &[@condition] {\n      --width: 200px;\n    }\n  "], ["\n    --width: 100px;\n\n    &[@condition] {\n      --width: 200px;\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useCustomProperties from 'cssta/runtime/useCustomProperties';\n    import VariablesContext from 'cssta/runtime/VariablesContext';\n    const Example = React.forwardRef(({\n      condition,\n      ...props\n    }, ref) => {\n      const exportedCustomProperties = {};\n      exportedCustomProperties['width'] = '100px';\n\n      if (condition === true) {\n        exportedCustomProperties['width'] = '200px';\n      }\n\n      const customProperties = useCustomProperties(exportedCustomProperties);\n      return <VariablesContext.Provider value={customProperties}><Element {...props} ref={ref} /></VariablesContext.Provider>;\n    });\"\n  ");
});
it("Supports multiple conditional exported variables", function () {
    var css = __testUtil__1.styled.test(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n    --width: 100px;\n    --height: 100px;\n\n    &[@condition] {\n      --width: 200px;\n      --height: 200px;\n    }\n  "], ["\n    --width: 100px;\n    --height: 100px;\n\n    &[@condition] {\n      --width: 200px;\n      --height: 200px;\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useCustomProperties from 'cssta/runtime/useCustomProperties';\n    import VariablesContext from 'cssta/runtime/VariablesContext';\n    const Example = React.forwardRef(({\n      condition,\n      ...props\n    }, ref) => {\n      const exportedCustomProperties = {};\n      exportedCustomProperties['width'] = '100px';\n      exportedCustomProperties['height'] = '100px';\n\n      if (condition === true) {\n        exportedCustomProperties['width'] = '200px';\n        exportedCustomProperties['height'] = '200px';\n      }\n\n      const customProperties = useCustomProperties(exportedCustomProperties);\n      return <VariablesContext.Provider value={customProperties}><Element {...props} ref={ref} /></VariablesContext.Provider>;\n    });\"\n  ");
});
it("Supports rules where only some import variables", function () {
    var css = __testUtil__1.styled.test(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n    width: 100px;\n\n    &[@cond1] {\n      width: var(--something);\n    }\n\n    &[@cond2] {\n      width: 200px;\n    }\n\n    &[@cond1] {\n      width: var(--somethingElse);\n    }\n  "], ["\n    width: 100px;\n\n    &[@cond1] {\n      width: var(--something);\n    }\n\n    &[@cond2] {\n      width: 200px;\n    }\n\n    &[@cond1] {\n      width: var(--somethingElse);\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useCustomProperties from 'cssta/runtime/useCustomProperties';\n    import useCustomPropertyStyles from 'cssta/runtime/useCustomPropertyStyles';\n    const styles0 = {\n      width: 100\n    };\n    const unresolvedStyleTuples0 = [['width', 'var(--something)']];\n    const styles1 = {\n      width: 200\n    };\n    const unresolvedStyleTuples1 = [['width', 'var(--somethingElse)']];\n    const Example = React.forwardRef(({\n      cond1,\n      cond2,\n      ...props\n    }, ref) => {\n      const customProperties = useCustomProperties(null);\n      const styles = useCustomPropertyStyles(unresolvedStyleTuples0, customProperties);\n      const styles2 = useCustomPropertyStyles(unresolvedStyleTuples1, customProperties);\n      const baseStyle = cond1 === true ? styles2 : cond2 === true ? styles1 : cond1 === true ? styles : styles0;\n      const style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports global variables in config", function () {
    var css = __testUtil__1.styled.test(templateObject_7 || (templateObject_7 = __makeTemplateObject(["\n    color: var(--primary);\n  "], ["\n    color: var(--primary);\n  "])));
    var code = __testUtil__1.build(css, {
        globals: {
            primary: "red"
        }
    });
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    const styles0 = {\n      color: 'red'\n    };\n    const Example = React.forwardRef((props, ref) => {\n      const style = props.style != null ? [styles0, props.style] : styles0;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Omits missing globals", function () {
    var css = __testUtil__1.styled.test(templateObject_8 || (templateObject_8 = __makeTemplateObject(["\n    color: var(--primary);\n    background: var(--secondary);\n  "], ["\n    color: var(--primary);\n    background: var(--secondary);\n  "])));
    var code = __testUtil__1.build(css, {
        globals: {
            primary: "red"
        }
    });
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useCustomProperties from 'cssta/runtime/useCustomProperties';\n    import useCustomPropertyStyles from 'cssta/runtime/useCustomPropertyStyles';\n    const unresolvedStyleTuples0 = [['color', 'red'], ['background', 'var(--secondary)']];\n    const Example = React.forwardRef((props, ref) => {\n      const customProperties = useCustomProperties(null);\n      const styles = useCustomPropertyStyles(unresolvedStyleTuples0, customProperties);\n      const style = props.style != null ? [styles, props.style] : styles;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Does not allow overwriting global variables", function () {
    var css = __testUtil__1.styled.test(templateObject_9 || (templateObject_9 = __makeTemplateObject(["\n    --primary: blue;\n  "], ["\n    --primary: blue;\n  "])));
    expect(function () {
        __testUtil__1.build(css, {
            globals: {
                primary: "red"
            }
        });
    }).toThrow('Attempted to overwrite global variable "primary". Either change this variable, or remove it from the globals. See line `--primary: blue`');
});
it("Supports failing build on missing global", function () {
    var css = __testUtil__1.styled.test(templateObject_10 || (templateObject_10 = __makeTemplateObject(["\n    color: var(--primary);\n    background: var(--secondary);\n  "], ["\n    color: var(--primary);\n    background: var(--secondary);\n  "])));
    expect(function () {
        __testUtil__1.build(css, {
            globals: {
                primary: "red"
            },
            globalVarsOnly: true
        });
    }).toThrow('Found variable "secondary". This was not defined in the globals, and `globalVarsOnly` is enabled. See line with `var(--secondary)`');
});
it("Does not fail failing build on missing global with globalVarsOnly if there is a fallback", function () {
    var css = __testUtil__1.styled.test(templateObject_11 || (templateObject_11 = __makeTemplateObject(["\n    color: var(--primary);\n    background: var(--secondary, orange);\n  "], ["\n    color: var(--primary);\n    background: var(--secondary, orange);\n  "])));
    var code = __testUtil__1.build(css, {
        globals: {
            primary: "red"
        },
        globalVarsOnly: true
    });
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    const styles0 = {\n      color: 'red',\n      backgroundColor: 'orange'\n    };\n    const Example = React.forwardRef((props, ref) => {\n      const style = props.style != null ? [styles0, props.style] : styles0;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports global variables with media queries", function () {
    var css = __testUtil__1.styled.test(templateObject_12 || (templateObject_12 = __makeTemplateObject(["\n    color: var(--primary);\n  "], ["\n    color: var(--primary);\n  "])));
    var code = __testUtil__1.build(css, {
        globals: "\n      --primary: red;\n\n      @media (prefers-color-scheme: dark) {\n        --primary: pink;\n      }\n    "
    });
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import { useColorScheme } from 'react-native';\n    const styles0 = {\n      color: 'red'\n    };\n    const styles1 = {\n      color: 'pink'\n    };\n    const Example = React.forwardRef((props, ref) => {\n      const colorScheme = useColorScheme();\n      const baseStyle = colorScheme === 'dark' ? styles1 : styles0;\n      const style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7, templateObject_8, templateObject_9, templateObject_10, templateObject_11, templateObject_12;
