"use strict";
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
exports.__esModule = true;
var __testUtil__1 = require("../__testUtil__");
it("Supports simple viewport units", function () {
    var css = __testUtil__1.styled.test(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n    width: 50vw;\n    height: 50vh;\n    max-height: 50vmax;\n    min-height: 50vmin;\n  "], ["\n    width: 50vw;\n    height: 50vh;\n    max-height: 50vmax;\n    min-height: 50vmin;\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n    const Example = React.forwardRef((props, ref) => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      const baseStyle = {\n        width: Number(windowWidth * 0.5),\n        height: Number(windowHeight * 0.5),\n        maxHeight: Number(Math.max(windowWidth, windowHeight) * 0.5),\n        minHeight: Number(Math.min(windowWidth, windowHeight) * 0.5)\n      };\n      const style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports fixed units with conditional simple viewport units", function () {
    var css = __testUtil__1.styled.test(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n    width: 100px;\n\n    &[@cond] {\n      width: 50vw;\n    }\n  "], ["\n    width: 100px;\n\n    &[@cond] {\n      width: 50vw;\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n    const styles0 = {\n      width: 100\n    };\n    const Example = React.forwardRef(({\n      cond,\n      ...props\n    }, ref) => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      const baseStyle = cond === true ? {\n        width: Number(windowWidth * 0.5)\n      } : styles0;\n      const style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports multiple conditional simple viewport units", function () {
    var css = __testUtil__1.styled.test(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n    width: 10vw;\n\n    &[@cond] {\n      width: 50vw;\n    }\n  "], ["\n    width: 10vw;\n\n    &[@cond] {\n      width: 50vw;\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n    const Example = React.forwardRef(({\n      cond,\n      ...props\n    }, ref) => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      const baseStyle = cond === true ? {\n        width: Number(windowWidth * 0.5)\n      } : {\n        width: Number(windowWidth * 0.1)\n      };\n      const style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports simple viewport units with conditional fixed units", function () {
    var css = __testUtil__1.styled.test(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n    width: 10vw;\n\n    &[@cond] {\n      width: 50px;\n    }\n  "], ["\n    width: 10vw;\n\n    &[@cond] {\n      width: 50px;\n    }\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useWindowDimensions from 'cssta/runtime/useWindowDimensions';\n    const styles0 = {\n      width: 50\n    };\n    const Example = React.forwardRef(({\n      cond,\n      ...props\n    }, ref) => {\n      const {\n        width: windowWidth,\n        height: windowHeight\n      } = useWindowDimensions();\n      const baseStyle = cond === true ? styles0 : {\n        width: Number(windowWidth * 0.1)\n      };\n      const style = props.style != null ? [baseStyle, props.style] : baseStyle;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports viewport units in shorthands", function () {
    var css = __testUtil__1.styled.test(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n    margin: 10vw;\n  "], ["\n    margin: 10vw;\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useViewportStyle from 'cssta/runtime/useViewportStyle';\n    const unresolvedStyleTuples0 = [['margin', '10vw']];\n    const Example = React.forwardRef((props, ref) => {\n      const styles0 = useViewportStyle(unresolvedStyleTuples0);\n      const style = props.style != null ? [styles0, props.style] : styles0;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
it("Supports simple viewport units with calc", function () {
    var css = __testUtil__1.styled.test(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n    width: calc(10vw - 100px);\n  "], ["\n    width: calc(10vw - 100px);\n  "])));
    var code = __testUtil__1.build(css);
    expect(code).toMatchInlineSnapshot("\n    \"import React from 'react';\n    import useViewportStyle from 'cssta/runtime/useViewportStyle';\n    const unresolvedStyleTuples0 = [['width', 'calc(10vw - 100px)']];\n    const Example = React.forwardRef((props, ref) => {\n      const styles0 = useViewportStyle(unresolvedStyleTuples0);\n      const style = props.style != null ? [styles0, props.style] : styles0;\n      return <Element {...props} ref={ref} style={style} />;\n    });\"\n  ");
});
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6;
