"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
/* eslint-disable @typescript-eslint/no-use-before-define */
var postcss_selector_parser_1 = __importDefault(require("postcss-selector-parser"));
var combineLogicalValidators = function (babel, operator, validators) {
    var t = babel.types;
    if (validators.length === 0) {
        throw new Error("Cannot construct logical validaton");
    }
    var nodeValidators = validators.filter(function (v) { return v != null; });
    if (nodeValidators.length === 0)
        return null;
    return nodeValidators
        .slice(1)
        .reduce(function (accum, validator) { return t.logicalExpression(operator, accum, validator); }, nodeValidators[0]);
};
var createLogicalValidator = function (babel, operator, nodes) {
    return combineLogicalValidators(babel, operator, nodes.map(function (node) { return createValidator(babel, node); }));
}; // eslint-disable-line
var createValidator = function (babel, node) {
    var t = babel.types;
    switch (node.type) {
        case "universal":
            return null;
        case "nesting":
            return null;
        case "attribute": {
            var value = node.value;
            var attribute = node.attribute.trim();
            if (node.ns !== "cssta") {
                throw new Error("You can only use prop selectors (did you forget an @ before " + attribute + ")");
            }
            var prop = t.identifier(attribute);
            var valueNode = value
                ? t.stringLiteral(value.trim())
                : t.booleanLiteral(true);
            return t.binaryExpression("===", prop, valueNode);
        }
        case "pseudo": {
            var value = node.value, nodes = node.nodes;
            if (value === ":matches") {
                return createLogicalValidator(babel, "||", nodes);
            }
            else if (value === ":not") {
                var baseValidator = createLogicalValidator(babel, "||", nodes);
                return baseValidator ? t.unaryExpression("!", baseValidator) : null;
            }
            throw new Error("Invalid selector part: " + node.toString());
        }
        case "selector":
            return createLogicalValidator(babel, "&&", node.nodes);
        case "root":
            return createLogicalValidator(babel, "||", node.nodes);
        default:
            return null;
    }
};
var aspectRatioWH = function (_a, str) {
    var t = _a.types;
    var _b = str
        .split("/")
        .map(function (x) { return x.trim(); })
        .map(Number), w = _b[0], h = _b[1];
    return t.binaryExpression("/", t.numericLiteral(w), t.numericLiteral(h));
};
var createMediaFeatureValidator = function (babel, query, env) {
    var t = babel.types;
    var match = query.match(/^\s*\(\s*([\w-]+)\s*:\s*(\S+(?:\s\S)*)\s*\)\s*$/);
    if (match == null)
        throw new Error("Could not parse media query: " + query);
    switch (match[1]) {
        case "platform":
            return t.binaryExpression("===", env.getPlatform(), t.stringLiteral(match[2]));
        case "prefers-color-scheme":
            return t.binaryExpression("===", env.getColorScheme(), t.stringLiteral(match[2]));
        case "width":
            return t.binaryExpression("===", env.getWindowWidth(), t.numericLiteral(parseInt(match[2], 10)));
        case "min-width":
            return t.binaryExpression(">=", env.getWindowWidth(), t.numericLiteral(parseInt(match[2], 10)));
        case "max-width":
            return t.binaryExpression("<=", env.getWindowWidth(), t.numericLiteral(parseInt(match[2], 10)));
        case "height":
            return t.binaryExpression("===", env.getWindowHeight(), t.numericLiteral(parseInt(match[2], 10)));
        case "min-height":
            return t.binaryExpression(">=", env.getWindowHeight(), t.numericLiteral(parseInt(match[2], 10)));
        case "max-height":
            return t.binaryExpression("<=", env.getWindowHeight(), t.numericLiteral(parseInt(match[2], 10)));
        case "aspect-ratio": {
            return t.binaryExpression("===", aspectRatioWH(babel, match[2]), t.binaryExpression("/", env.getWindowWidth(), env.getWindowHeight()));
        }
        case "min-aspect-ratio": {
            return t.binaryExpression("<=", aspectRatioWH(babel, match[2]), t.binaryExpression("/", env.getWindowWidth(), env.getWindowHeight()));
        }
        case "max-aspect-ratio": {
            return t.binaryExpression(">=", aspectRatioWH(babel, match[2]), t.binaryExpression("/", env.getWindowWidth(), env.getWindowHeight()));
        }
        case "orientation": {
            if (/landscape/i.test(match[2])) {
                return t.binaryExpression(">", env.getWindowWidth(), env.getWindowHeight());
            }
            else if (/portrait/i.test(match[2])) {
                return t.binaryExpression("<", env.getWindowWidth(), env.getWindowHeight());
            }
        }
        // fallthrough
        default:
            throw new Error("Could not parse media query: " + query);
    }
};
var createMediaQueryValidator = function (babel, mediaQuery, environment) {
    if (mediaQuery == null)
        return null;
    var createMediaQueryPartValidator = function (queryPart) {
        return combineLogicalValidators(babel, "&&", (queryPart.match(/\([^()]+\)/g) || []).map(function (query) {
            return createMediaFeatureValidator(babel, query, environment);
        }));
    };
    var mediaQueryValidators = mediaQuery
        .split(",")
        .map(createMediaQueryPartValidator);
    var mediaQueryValidator = combineLogicalValidators(babel, "||", mediaQueryValidators);
    return mediaQueryValidator;
};
exports["default"] = (function (babel, _a, environment) {
    var selector = _a.selector, mediaQuery = _a.mediaQuery;
    var selectorNode;
    postcss_selector_parser_1["default"](function (node) {
        selectorNode = node;
    }).processSync(selector);
    if (!selectorNode)
        throw new Error("Expected to parse selector");
    var validatorNode = combineLogicalValidators(babel, "&&", [
        createValidator(babel, selectorNode),
        createMediaQueryValidator(babel, mediaQuery, environment)
    ]);
    return validatorNode;
});
