"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var extractRules_1 = __importDefault(require("../css/extractRules"));
var types_1 = require("../css/types");
var extractSubstitutionMap_1 = __importDefault(require("./extractSubstitutionMap"));
var environment_1 = __importDefault(require("./environment"));
var styleSheet_1 = __importDefault(require("./styleSheet"));
var style_1 = __importDefault(require("./style"));
var useCustomProperties_1 = __importDefault(require("./useCustomProperties"));
var useTransition_1 = __importDefault(require("./useTransition"));
var useKeyframes_1 = __importDefault(require("./useKeyframes"));
var useAnimation_1 = __importDefault(require("./useAnimation"));
var returnElement_1 = __importDefault(require("./returnElement"));
var forwardRefComponent_1 = __importDefault(require("./forwardRefComponent"));
exports["default"] = (function (babel, nodePath, elementNode, cssNode, options) {
    var _a = extractSubstitutionMap_1["default"](cssNode), cssText = _a.cssText, substitutionMap = _a.substitutionMap;
    var cssOutput = extractRules_1["default"](cssText, options);
    var propTypes = cssOutput.propTypes, styles = cssOutput.styles, transitions = cssOutput.transitions, animations = cssOutput.animations, keyframes = cssOutput.keyframes, exportedVariables = cssOutput.exportedVariables;
    var _b = forwardRefComponent_1["default"](babel, nodePath, { propTypes: propTypes }), path = _b.path, propsVariable = _b.propsVariable, refVariable = _b.refVariable;
    var environment = environment_1["default"](babel, path);
    var hasImportedVariables = styles.some(function (x) { return x.type === types_1.StyleType.Tuples && x.importedVariables.length !== 0; }) ||
        transitions.some(function (x) { return x.importedVariables.length !== 0; }) ||
        animations.some(function (x) { return x.importedVariables.length !== 0; }) ||
        keyframes.some(function (x) { return x.importedVariables.length !== 0; }) ||
        exportedVariables.some(function (x) { return x.importedVariables.length !== 0; });
    var hasExportedVariables = exportedVariables.length !== 0;
    if (hasExportedVariables && options != null && options.globals != null) {
        exportedVariables.forEach(function (_a) {
            var name = _a.name, value = _a.value;
            if (options.globals[name] != null) {
                throw new Error("Attempted to overwrite global variable \"" + name + "\". Either change this variable, or remove it from the globals. See line `--" + name + ": " + value + "`");
            }
        });
    }
    var customPropertiesVariable;
    if (hasImportedVariables || hasExportedVariables) {
        customPropertiesVariable = useCustomProperties_1["default"](babel, path, cssOutput, environment);
    }
    var styleSheetRuleExpressions = styleSheet_1["default"](babel, path, cssOutput, substitutionMap, environment, { customPropertiesVariable: customPropertiesVariable });
    var willModifyStyle = transitions.length !== 0 || animations.length !== 0;
    var styleVariable = style_1["default"](babel, path, environment, {
        propsVariable: propsVariable,
        styleSheetRuleExpressions: styleSheetRuleExpressions,
        willModifyStyle: willModifyStyle
    });
    if (transitions.length !== 0) {
        useTransition_1["default"](babel, path, cssOutput, environment, {
            styleVariable: styleVariable,
            customPropertiesVariable: customPropertiesVariable
        });
    }
    var keyframesVariable;
    if (keyframes.length !== 0) {
        keyframesVariable = useKeyframes_1["default"](babel, path, cssOutput);
    }
    if (animations.length !== 0) {
        useAnimation_1["default"](babel, path, cssOutput, environment, {
            styleVariable: styleVariable,
            keyframesVariable: keyframesVariable,
            customPropertiesVariable: customPropertiesVariable
        });
    }
    returnElement_1["default"](babel, path, elementNode, options, {
        propsVariable: propsVariable,
        refVariable: refVariable,
        styleVariable: styleVariable,
        hasExportedVariables: hasExportedVariables,
        customPropertiesVariable: customPropertiesVariable
    });
    path.scope.crawl();
});
