"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var extractRules_1 = __importDefault(require("../css/extractRules"));
var types_1 = require("../css/types");
var extractSubstitutionMap_1 = __importDefault(require("./extractSubstitutionMap"));
var environment_1 = __importDefault(require("./environment"));
var styleSheet_1 = __importDefault(require("./styleSheet"));
var style_1 = __importDefault(require("./style"));
var useCustomProperties_1 = __importDefault(require("./useCustomProperties"));
exports["default"] = (function (babel, nodePath, cssNode, options) {
    var _a = extractSubstitutionMap_1["default"](cssNode), cssText = _a.cssText, substitutionMap = _a.substitutionMap;
    var cssOutput = extractRules_1["default"](cssText, options);
    var styles = cssOutput.styles, transitions = cssOutput.transitions, animations = cssOutput.animations, keyframes = cssOutput.keyframes, exportedVariables = cssOutput.exportedVariables;
    if (transitions.length !== 0) {
        throw new Error("You cannot define transitions in a mixin");
    }
    else if (animations.length !== 0) {
        throw new Error("You cannot define animations in a mixin");
    }
    else if (keyframes.length !== 0) {
        throw new Error("You cannot define keyframes in a mixin");
    }
    else if (exportedVariables.length !== 0) {
        throw new Error("You cannot define CSS custom properties in a mixin");
    }
    var t = babel.types;
    nodePath.replaceWith(t.arrowFunctionExpression([], t.blockStatement([])));
    var path = nodePath.get("body");
    var environment = environment_1["default"](babel, path);
    var hasImportedVariables = styles.some(function (rule) {
        return rule.type === types_1.StyleType.Tuples && rule.importedVariables.length !== 0;
    });
    var customPropertiesVariable;
    if (hasImportedVariables) {
        customPropertiesVariable = useCustomProperties_1["default"](babel, path, cssOutput, environment);
    }
    var styleSheetRuleExpressions = styleSheet_1["default"](babel, path, cssOutput, substitutionMap, environment, { customPropertiesVariable: customPropertiesVariable });
    var styleVariable = style_1["default"](babel, path, environment, {
        styleSheetRuleExpressions: styleSheetRuleExpressions
    });
    path.pushContainer("body", t.returnStatement(styleVariable));
    path.scope.crawl();
});
