"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var babel = __importStar(require("@babel/core"));
var generator_1 = __importDefault(require("@babel/generator"));
var styleBody_1 = __importDefault(require("../styleBody"));
var t = babel.types;
var run = function (substitutionMap, styleTuples) {
    var ast = babel.parse("const styles = () => {}");
    babel.traverse(ast, {
        ArrowFunctionExpression: function (path) {
            var node = styleBody_1["default"](babel, path.get("body"), substitutionMap, styleTuples);
            path.get("body").pushContainer("body", t.returnStatement(node));
        }
    });
    var code = generator_1["default"](ast).code;
    return code.replace(/"/g, "'");
};
it("Does not transform without substitutions", function () {
    var code = run({}, [["color", "red"]]);
    expect(code).toMatchInlineSnapshot("\n    \"const styles = () => {\n      return {\n        color: 'red'\n      };\n    };\"\n  ");
});
it("Transforms string substitutions", function () {
    var code = run({ int1: t.identifier("color") }, [["color", "int1"]]);
    expect(code).toMatchInlineSnapshot("\n    \"const styles = () => {\n      return {\n        color: String(color).trim()\n      };\n    };\"\n  ");
});
it("Transforms number substitutions", function () {
    var code = run({ int1: t.identifier("opacity") }, [["opacity", "int1"]]);
    expect(code).toMatchInlineSnapshot("\n    \"const styles = () => {\n      return {\n        opacity: Number(opacity)\n      };\n    };\"\n  ");
});
it("Transforms length substitutions", function () {
    var code = run({ int1: t.identifier("top") }, [["top", "int1"]]);
    expect(code).toMatchInlineSnapshot("\n    \"import { transformRawValue } from 'cssta/runtime/cssUtil';\n\n    const styles = () => {\n      return {\n        top: transformRawValue(top)\n      };\n    };\"\n  ");
});
it("Transforms shorthand values", function () {
    var code = run({ int1: t.identifier("margin") }, [["margin", "int1"]]);
    expect(code).toMatchInlineSnapshot("\n    \"import { transformStyleTuples } from 'cssta/runtime/cssUtil';\n\n    const styles = () => {\n      return transformStyleTuples([['margin', `${margin}`]]);\n    };\"\n  ");
});
it("Combines a simple value before a shorthand value", function () {
    var code = run({ int1: t.identifier("opacity"), int2: t.identifier("margin") }, [
        ["opacity", "int1"],
        ["margin", "int2"]
    ]);
    expect(code).toMatchInlineSnapshot("\n    \"import { transformStyleTuples } from 'cssta/runtime/cssUtil';\n\n    const styles = () => {\n      return Object.assign({\n        opacity: Number(opacity)\n      }, transformStyleTuples([['margin', `${margin}`]]));\n    };\"\n  ");
});
it("Combines a simple value after a shorthand value", function () {
    var code = run({ int1: t.identifier("margin"), int2: t.identifier("opacity") }, [
        ["margin", "int2"],
        ["opacity", "int1"]
    ]);
    expect(code).toMatchInlineSnapshot("\n    \"import { transformStyleTuples } from 'cssta/runtime/cssUtil';\n\n    const styles = () => {\n      return Object.assign(transformStyleTuples([['margin', `${opacity}`]]), {\n        opacity: Number(margin)\n      });\n    };\"\n  ");
});
it("Combines multiple simple values with a shorthand value", function () {
    var code = run({
        int1: t.identifier("top"),
        int2: t.identifier("right"),
        int3: t.identifier("margin"),
        int4: t.identifier("color"),
        int5: t.identifier("left"),
        int6: t.identifier("border"),
        int7: t.identifier("opacity")
    }, [
        ["top", "int1"],
        ["right", "int2"],
        ["margin", "int3"],
        ["color", "int4"],
        ["left", "int5"],
        ["border", "int6"],
        ["opacity", "int7"]
    ]);
    expect(code).toMatchInlineSnapshot("\n    \"import { transformRawValue } from 'cssta/runtime/cssUtil';\n    import { transformStyleTuples } from 'cssta/runtime/cssUtil';\n\n    const styles = () => {\n      return Object.assign({\n        top: transformRawValue(top),\n        right: transformRawValue(right)\n      }, transformStyleTuples([['margin', `${margin}`]]), {\n        color: String(color).trim(),\n        left: transformRawValue(left)\n      }, transformStyleTuples([['border', `${border}`]]), {\n        opacity: Number(opacity)\n      });\n    };\"\n  ");
});
it("Does not allow multiple values for simple properties", function () {
    expect(function () {
        run({
            int1: t.identifier("color1"),
            int2: t.identifier("color2")
        }, [["color", "int1 int2"]]);
    }).toThrow("Used multiple values color, which accepts one value");
});
it("Allows multiple values for shorthand properties", function () {
    var code = run({
        int1: t.identifier("margin1"),
        int2: t.identifier("margin2")
    }, [["margin", "int1 int2"]]);
    expect(code).toMatchInlineSnapshot("\n    \"import { transformStyleTuples } from 'cssta/runtime/cssUtil';\n\n    const styles = () => {\n      return transformStyleTuples([['margin', `${margin1} ${margin2}`]]);\n    };\"\n  ");
});
it("Doesn't fail with empty substitution map", function () {
    expect(function () { return run({}, [["margin", "0"]]); }).not.toThrow();
});
