"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var types_1 = require("../../css/types");
var util_1 = require("../util");
var styleBody_1 = __importDefault(require("./styleBody"));
var styleTuples_1 = require("./styleTuples");
var viewport_1 = require("./viewport");
var OptimizationFlag;
(function (OptimizationFlag) {
    OptimizationFlag[OptimizationFlag["None"] = 0] = "None";
    OptimizationFlag[OptimizationFlag["SupersetsPrevious"] = 1] = "SupersetsPrevious";
})(OptimizationFlag = exports.OptimizationFlag || (exports.OptimizationFlag = {}));
var createVariablesStyleExpression = function (babel, path, _a, styleTuples) {
    var substitutionMap = _a.substitutionMap, customPropertiesVariable = _a.customPropertiesVariable, viewportMode = _a.viewportMode;
    var t = babel.types;
    var baseUnresolvedStyleTuplesVariable = styleTuples_1.createTopLevelStyleTuplesVariable(babel, path, substitutionMap, styleTuples);
    var unresolvedStyleTuplesVariable;
    if (viewportMode === viewport_1.ViewportMode.None) {
        unresolvedStyleTuplesVariable = baseUnresolvedStyleTuplesVariable;
    }
    else {
        if (Object.keys(substitutionMap).length !== 0) {
            throw new Error("String interpolation (${value}) is not yet supported when in combination with viewport units or CSS custom properties");
        }
        var useViewportStyleTuplesImport = util_1.getOrCreateImport(babel, path, "cssta/runtime/useViewportStyleTuples");
        unresolvedStyleTuplesVariable = util_1.createVariable(babel, path, "unresolvedStyleTuples", t.callExpression(useViewportStyleTuplesImport, [
            baseUnresolvedStyleTuplesVariable
        ]), { prefix0: true });
    }
    var useCustomPropertyStylesImport = util_1.getOrCreateImport(babel, path, "cssta/runtime/useCustomPropertyStyles");
    var styleExpression = util_1.createVariable(babel, path, "styles", t.callExpression(useCustomPropertyStylesImport, [
        unresolvedStyleTuplesVariable,
        customPropertiesVariable
    ]));
    return styleExpression;
};
var createStyleExpression = function (babel, path, substitutionMap, environment, customPropertiesVariable, rule, comment) {
    var t = babel.types;
    var styleTuples = rule.styleTuples, importedVariables = rule.importedVariables;
    var viewportMode = viewport_1.getViewportMode(rule);
    var importsVariables = importedVariables.length !== 0;
    var styleExpression;
    if (importsVariables) {
        styleExpression = createVariablesStyleExpression(babel, path, { substitutionMap: substitutionMap, customPropertiesVariable: customPropertiesVariable, viewportMode: viewportMode }, styleTuples);
    }
    else if (viewportMode === viewport_1.ViewportMode.ComplexUnits) {
        var unresolvedStyleTuplesVariable = styleTuples_1.createTopLevelStyleTuplesVariable(babel, path, substitutionMap, styleTuples);
        var cssToReactNativeImport = util_1.getOrCreateImport(babel, path, "cssta/runtime/useViewportStyle");
        styleExpression = util_1.createVariable(babel, path, "styles", t.callExpression(cssToReactNativeImport, [unresolvedStyleTuplesVariable]), { prefix0: true });
    }
    else if (viewportMode === viewport_1.ViewportMode.SimpleLengthUnits) {
        var _a = viewport_1.interpolateViewportUnits(babel, substitutionMap, environment, styleTuples), nextSubstitutionMap = _a[0], styleTuplesWithViewportSubstitutions = _a[1];
        styleExpression = styleBody_1["default"](babel, path, nextSubstitutionMap, styleTuplesWithViewportSubstitutions);
    }
    else {
        var style = styleBody_1["default"](babel, path, substitutionMap, styleTuples);
        if (comment != null) {
            style.leadingComments = [{ type: "CommentBlock", value: " " + comment + " " }];
        }
        styleExpression = util_1.createTopLevelVariable(babel, path, "styles", style, {
            prefix0: true
        });
    }
    return styleExpression;
};
var createMixinExpression = function (babel, path, substitutionMap, rule) {
    var t = babel.types;
    var substitution = substitutionMap[rule.substitution];
    if (substitution == null) {
        throw new Error("Mixins should use interpolation (e.g. @include ${useStyles})");
    }
    return util_1.createVariable(babel, path, "mixinInclude", t.callExpression(t.cloneDeep(substitution), []), { prefix0: true });
};
var mergeFirstStyleIntoAllRules = function (styles) {
    var mergeeRule = styles[0];
    var stylesMerged = styles.map(function (rule) {
        if (rule === mergeeRule)
            return rule;
        var ownStyleKeys = new Set(rule.styleTuples.map(function (styleTuple) { return styleTuple[0]; }));
        var stylesToMerge = mergeeRule.styleTuples.filter(function (styleTuple) { return !ownStyleKeys.has(styleTuple[0]); });
        if (stylesToMerge.length === 0)
            return rule;
        var mergedStyleTuples = __spreadArrays(stylesToMerge, rule.styleTuples);
        return __assign(__assign({}, rule), { styleTuples: mergedStyleTuples });
    });
    return stylesMerged;
};
var getOptimizationFlag = function (styles) {
    var lastStyleKeys = null;
    return styles.map(function (rule) {
        if (rule.type === types_1.StyleType.Mixin) {
            lastStyleKeys = null;
            return OptimizationFlag.None;
        }
        var ownStyleKeys = rule.styleTuples.map(function (styleTuple) { return styleTuple[0]; });
        var supersets = lastStyleKeys != null &&
            lastStyleKeys.every(function (key) { return ownStyleKeys.includes(key); });
        lastStyleKeys = ownStyleKeys;
        return supersets
            ? OptimizationFlag.SupersetsPrevious
            : OptimizationFlag.None;
    });
};
exports["default"] = (function (babel, path, _a, substitutionMap, environment, _b) {
    var styles = _a.styles;
    var customPropertiesVariable = _b.customPropertiesVariable;
    var styleSheetRuleExpressions;
    if (styles.length === 2 &&
        styles[0].condition == null &&
        styles.every(function (style) { return style.type === types_1.StyleType.Tuples; })) {
        var mergedStyleTuples_1 = mergeFirstStyleIntoAllRules(styles);
        styleSheetRuleExpressions = mergedStyleTuples_1.map(function (rule, i) {
            var didMergeStyleTuples = rule !== mergedStyleTuples_1[i];
            var comment = didMergeStyleTuples
                ? "Some styles have been duplicated to improve performance"
                : null;
            var condition = rule.condition;
            var expression = createStyleExpression(babel, path, substitutionMap, environment, customPropertiesVariable, rule, comment);
            var optimizationFlag = i !== 0 ? OptimizationFlag.SupersetsPrevious : OptimizationFlag.None;
            return { condition: condition, expression: expression, optimizationFlag: optimizationFlag };
        });
    }
    else {
        var stylesheetOptimizationFlags_1 = getOptimizationFlag(styles);
        var styleSheetExpressions_1 = styles.map(function (rule) {
            return rule.type === types_1.StyleType.Tuples
                ? createStyleExpression(babel, path, substitutionMap, environment, customPropertiesVariable, rule)
                : createMixinExpression(babel, path, substitutionMap, rule);
        });
        styleSheetRuleExpressions = styles.map(function (style, i) { return ({
            condition: style.condition,
            expression: styleSheetExpressions_1[i],
            optimizationFlag: stylesheetOptimizationFlags_1[i]
        }); });
    }
    return styleSheetRuleExpressions;
});
