"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var css_to_react_native_1 = require("css-to-react-native");
var cssUtil_1 = require("../../../runtime/cssUtil");
var util_1 = require("../util");
var substitutionUtil_1 = require("./substitutionUtil");
var simpleUnitTypes_1 = __importDefault(require("./simpleUnitTypes"));
var substituteSimpleUnit_1 = __importDefault(require("./substituteSimpleUnit"));
var util_2 = require("./util");
var InterpolationType;
(function (InterpolationType) {
    InterpolationType[InterpolationType["NoOrSimple"] = 0] = "NoOrSimple";
    InterpolationType[InterpolationType["Template"] = 1] = "Template";
})(InterpolationType || (InterpolationType = {}));
var getInterpolationType = function (substitutionMap, _a) {
    var prop = _a[0], value = _a[1];
    if (!substitutionUtil_1.containsSubstitution(substitutionMap, value)) {
        return InterpolationType.NoOrSimple;
    }
    else if (css_to_react_native_1.getPropertyName(prop) in simpleUnitTypes_1["default"] && !util_2.calcRe.test(value)) {
        return InterpolationType.NoOrSimple;
    }
    return InterpolationType.Template;
};
var createStyleTupleGroups = function (substitutionMap, styleTuples) {
    var groups = [];
    styleTuples.forEach(function (styleTuple) {
        var interpolationType = getInterpolationType(substitutionMap, styleTuple);
        var lastGroup = groups[groups.length - 1];
        if (lastGroup != null &&
            lastGroup.interpolationType === interpolationType) {
            lastGroup.styleTuplesGroup.push(styleTuple);
        }
        else {
            groups.push({ interpolationType: interpolationType, styleTuplesGroup: [styleTuple] });
        }
    }, []);
    return groups;
};
var createSimpleNoInterpolationStyleMap = function (babel, path, substitutionMap, styleTuplesGroup) {
    var t = babel.types;
    var substitutionRegExp = Object.keys(substitutionMap).length !== 0
        ? substitutionUtil_1.getSubstitutionRegExp(substitutionMap)
        : null;
    var styleMap = {};
    styleTuplesGroup.forEach(function (_a) {
        var prop = _a[0], value = _a[1];
        var propertyName = css_to_react_native_1.getPropertyName(prop);
        var substitutionMatches = substitutionRegExp
            ? value.match(substitutionRegExp)
            : null;
        if (substitutionMatches == null) {
            var styles = cssUtil_1.transformStyleTuples([[propertyName, value]]);
            Object.entries(styles).forEach(function (_a) {
                var key = _a[0], value = _a[1];
                styleMap[key] = util_1.jsonToNode(babel, value);
            });
        }
        else if (substitutionMatches.length === 1) {
            var substitution = substitutionMatches[0] === value.trim()
                ? t.cloneDeep(substitutionMap[value])
                : substitutionUtil_1.getStringWithSubstitutedValues(babel, substitutionMap, value);
            styleMap[propertyName] = substituteSimpleUnit_1["default"](babel, path, propertyName, substitution);
        }
        else {
            throw new Error("Used multiple values " + propertyName + ", which accepts one value");
        }
    }, {});
    return styleMap;
};
var transformStyleTupleGroup = function (babel, path, substitutionMap, _a) {
    var styleTuplesGroup = _a.styleTuplesGroup, interpolationType = _a.interpolationType;
    var t = babel.types;
    if (interpolationType === InterpolationType.NoOrSimple) {
        var styleMap = createSimpleNoInterpolationStyleMap(babel, path, substitutionMap, styleTuplesGroup);
        return t.objectExpression(Object.entries(styleMap).map(function (_a) {
            var key = _a[0], value = _a[1];
            return t.objectProperty(t.identifier(key), value);
        }));
    }
    else if (interpolationType === InterpolationType.Template) {
        var cssToReactNativeImport = util_1.getOrCreateImport(babel, path, "cssta/runtime/cssUtil", "transformStyleTuples");
        var bodyPairs = t.arrayExpression(styleTuplesGroup.map(function (_a) {
            var prop = _a[0], value = _a[1];
            return t.arrayExpression([
                t.stringLiteral(css_to_react_native_1.getPropertyName(prop)),
                substitutionUtil_1.getStringWithSubstitutedValues(babel, substitutionMap, value)
            ]);
        }));
        return t.callExpression(cssToReactNativeImport, [bodyPairs]);
    }
    throw new Error("No interpolation type specified");
};
exports["default"] = (function (babel, path, substitutionMap, styleTuples) {
    var t = babel.types;
    var tupleGroups = createStyleTupleGroups(substitutionMap, styleTuples);
    var transformedGroups = tupleGroups.map(function (tupleGroup) {
        return transformStyleTupleGroup(babel, path, substitutionMap, tupleGroup);
    });
    if (transformedGroups.length === 0) {
        return null;
    }
    else if (transformedGroups.length === 1) {
        return transformedGroups[0];
    }
    return t.callExpression(t.memberExpression(t.identifier("Object"), t.identifier("assign")), transformedGroups);
});
