"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var flattenAnimation_1 = __importDefault(require("../../runtime/flattenAnimation"));
var buildCondition_1 = __importDefault(require("./buildCondition"));
var util_1 = require("./util");
exports["default"] = (function (babel, path, cssOutput, environment, _a) {
    var styleVariable = _a.styleVariable, keyframesVariable = _a.keyframesVariable, customPropertiesVariable = _a.customPropertiesVariable;
    var t = babel.types;
    var animations = cssOutput.animations;
    // FIXME: We could be more granular than useCustomPropertyShorthandParts whenever one part has a variable in
    var animationImportsVariables = animations.some(function (animation) { return animation.importedVariables.length > 0; });
    var animationExpression;
    var animationPartsExpression;
    if (animations.length === 0) {
        animationExpression = t.nullLiteral();
    }
    else if (!animationImportsVariables &&
        animations.length === 1 &&
        animations[0].condition == null) {
        animationExpression = util_1.createTopLevelVariable(babel, path, "animation", util_1.jsonToNode(babel, flattenAnimation_1["default"]([animations[0].part])));
    }
    else {
        animationPartsExpression = t.arrayExpression(animations.map(function (_a) {
            var condition = _a.condition, part = _a.part;
            var parts = util_1.jsonToNode(babel, part);
            return condition == null
                ? parts
                : t.conditionalExpression(buildCondition_1["default"](babel, condition, environment), parts, t.nullLiteral());
        }));
    }
    if (animationImportsVariables) {
        var useCustomPropertyShorthandPartsImport = util_1.getOrCreateImport(babel, path, "cssta/runtime/useCustomPropertyShorthandParts");
        var unresolvedAnimationPartsVariable = util_1.createVariable(babel, path, "unresolvedAnimationParts", animationPartsExpression);
        var useCustomPropertyAnimation = t.callExpression(useCustomPropertyShorthandPartsImport, [unresolvedAnimationPartsVariable, customPropertiesVariable]);
        animationPartsExpression = util_1.createVariable(babel, path, "animationParts", useCustomPropertyAnimation);
    }
    if (animationExpression == null) {
        var flattenAnimationFnImport = util_1.getOrCreateImport(babel, path, "cssta/runtime/flattenAnimation");
        animationExpression = util_1.createVariable(babel, path, "animation", t.callExpression(flattenAnimationFnImport, [animationPartsExpression]));
    }
    var useAnimationImport = util_1.getOrCreateImport(babel, path, "cssta/runtime/useAnimation");
    path.pushContainer("body", t.expressionStatement(t.assignmentExpression("=", styleVariable, t.callExpression(useAnimationImport, [
        keyframesVariable,
        animationExpression,
        styleVariable
    ]))));
});
