"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var buildCondition_1 = __importDefault(require("./buildCondition"));
var util_1 = require("./util");
var conditionsEqual = function (a, b) {
    if (a == null) {
        return b == null;
    }
    else if (b == null) {
        return false;
    }
    else {
        return a.selector === b.selector && a.mediaQuery === b.mediaQuery;
    }
};
exports["default"] = (function (babel, path, cssOutput, environment) {
    var t = babel.types;
    var exportedVariables = cssOutput.exportedVariables;
    var groups = [];
    exportedVariables.forEach(function (exportedVariables) {
        var condition = exportedVariables.condition;
        var lastGroup = groups[groups.length - 1];
        var group;
        if (lastGroup == null || !conditionsEqual(lastGroup.condition, condition)) {
            group = { condition: condition, values: [] };
            groups.push(group);
        }
        else {
            group = lastGroup;
        }
        group.values.push(exportedVariables);
    });
    var bloomFilterExpression;
    var exportedVariablesExpression;
    if (groups.length === 0) {
        /*
        We can use a bloom filter to ignore updates from variables we don't use, but
        we can only do this if we do not export variables. Otherwise we will skip
        updates from variables from child components
        */
        // const allImports = new Set([
        //   ...importedRuleVariables,
        //   ...importedTransitionVariables,
        //   ...importedAnimationVariables,
        //   ...importedKeyframeVariables
        // ]);
        // const bloomFilter = Array.from(allImports, keyBloom).reduce(
        //   (a, b) => a | b,
        //   0
        // );
        exportedVariablesExpression = t.nullLiteral();
        // bloomFilterExpression = t.numericLiteral(bloomFilter);
        bloomFilterExpression = null; // Not supported by React yet :(
    }
    else if (groups.length === 1) {
        var group = groups[0];
        var constantExportedVariables = t.objectExpression(group.values.map(function (_a) {
            var name = _a.name, value = _a.value;
            return t.objectProperty(t.stringLiteral(name), t.stringLiteral(value));
        }));
        var exportedVariablesVariable = util_1.createTopLevelVariable(babel, path, "exportedCustomProperties", constantExportedVariables);
        exportedVariablesExpression =
            group.condition == null
                ? exportedVariablesVariable
                : t.conditionalExpression(buildCondition_1["default"](babel, group.condition, environment), exportedVariablesVariable, t.nullLiteral());
    }
    else {
        var exportedPropertiesVariable_1 = util_1.createVariable(babel, path, "exportedCustomProperties", t.objectExpression([]));
        groups.forEach(function (_a) {
            var condition = _a.condition, values = _a.values;
            var assignments = values.map(function (_a) {
                var name = _a.name, value = _a.value;
                return t.expressionStatement(t.assignmentExpression("=", t.memberExpression(exportedPropertiesVariable_1, t.stringLiteral(name), true /* computed */), t.stringLiteral(value)));
            });
            if (condition == null) {
                path.pushContainer("body", assignments);
            }
            else {
                path.pushContainer("body", t.ifStatement(buildCondition_1["default"](babel, condition, environment), t.blockStatement(assignments)));
            }
        });
        exportedVariablesExpression = exportedPropertiesVariable_1;
    }
    var useCustomPropertiesImport = util_1.getOrCreateImport(babel, path, "cssta/runtime/useCustomProperties");
    var customProperties = t.callExpression(useCustomPropertiesImport, bloomFilterExpression != null
        ? [exportedVariablesExpression, bloomFilterExpression]
        : [exportedVariablesExpression]);
    var customPropertiesVariable = util_1.createVariable(babel, path, "customProperties", customProperties);
    return customPropertiesVariable;
});
