"use strict";
exports.__esModule = true;
exports.generateNiceId = function (babel, path, name, _a) {
    var _b = (_a === void 0 ? {} : _a).prefix0, prefix0 = _b === void 0 ? false : _b;
    var t = babel.types;
    var testId = prefix0 ? name + "0" : name;
    var i = 1;
    while (path.scope.hasBinding(testId) && i < 20) {
        testId = "" + name + i;
        i += 1;
    }
    return t.identifier(testId);
};
exports.createVariable = function (babel, path, name, init, _a) {
    var _b = _a === void 0 ? {} : _a, _c = _b.kind, kind = _c === void 0 ? "const" : _c, prefix0 = _b.prefix0;
    var t = babel.types;
    var id = exports.generateNiceId(babel, path, name, { prefix0: prefix0 });
    var declaration = t.variableDeclaration(kind, [
        t.variableDeclarator(id, init)
    ]);
    var declarationPath = path.pushContainer("body", declaration)[0];
    path.scope.registerDeclaration(declarationPath);
    return id;
};
exports.createTopLevelVariable = function (babel, path, name, init, idOpts) {
    var t = babel.types;
    var id = exports.generateNiceId(babel, path, name, idOpts);
    var declaration = t.variableDeclaration("const", [
        t.variableDeclarator(id, init)
    ]);
    var statementPath = path.getStatementParent();
    var declarationPath = statementPath.insertBefore(declaration)[0];
    statementPath.scope.registerDeclaration(declarationPath);
    return id;
};
exports.jsonToNode = function (babel, object) {
    var t = babel.types;
    if (typeof object === "string") {
        return t.stringLiteral(object);
    }
    else if (typeof object === "number") {
        return t.numericLiteral(object);
    }
    else if (Array.isArray(object)) {
        return t.arrayExpression(object.map(function (element) { return exports.jsonToNode(babel, element); }));
    }
    else if (object === null) {
        return t.nullLiteral();
    }
    return t.objectExpression(Object.keys(object).map(function (key) {
        return t.objectProperty(t.stringLiteral(key), exports.jsonToNode(babel, object[key]));
    }));
};
exports.getImportBindings = function (_a, path, moduleName, importedName) {
    var t = _a.types;
    if (importedName === void 0) { importedName = "default"; }
    var allBindings = Object.values(path.scope.getAllBindingsOfKind("module"));
    var allImportBindings = importedName === "default"
        ? allBindings.filter(function (reference) {
            return t.isImportDefaultSpecifier(reference.path.node);
        })
        : allBindings.filter(function (reference) {
            return t.isImportSpecifier(reference.path.node) &&
                reference.path.node.imported.name === importedName;
        });
    var importBindingsForModule = allImportBindings.filter(function (reference) {
        var importDeclaration = reference.path.findParent(t.isImportDeclaration);
        var importModuleName = importDeclaration.node.source.value;
        return importModuleName === moduleName;
    });
    return importBindingsForModule;
};
exports.getImportBinding = function (babel, path, moduleName, importedName) { return exports.getImportBindings(babel, path, moduleName, importedName)[0]; };
exports.getOrCreateImport = function (babel, path, moduleName, importedName, _a) {
    if (importedName === void 0) { importedName = "default"; }
    var preferredName = (_a === void 0 ? {} : _a).preferredName;
    var t = babel.types;
    var binding = exports.getImportBinding(babel, path, moduleName, importedName);
    if (binding) {
        return t.cloneDeep(binding.identifier);
    }
    var reference;
    if (preferredName != null) {
        reference = exports.generateNiceId(babel, path, preferredName);
    }
    else if (importedName !== "default") {
        reference = exports.generateNiceId(babel, path, importedName);
    }
    else {
        var referenceMatch = moduleName.match(/(?:\/|^)([^/]+)$/);
        var referenceName = referenceMatch ? referenceMatch[1] : moduleName;
        reference = exports.generateNiceId(babel, path, referenceName);
    }
    var importSpecifier = importedName === "default"
        ? t.importDefaultSpecifier(reference)
        : t.importSpecifier(reference, t.identifier(importedName));
    var importDeclaration = t.importDeclaration([importSpecifier], t.stringLiteral(moduleName));
    var programPath = path.findParent(t.isProgram);
    path.scope.getProgramParent().references[reference.name] = true;
    var body = programPath.get("body");
    var importDeclarations = body.filter(t.isImportDeclaration);
    var importDeclarationPaths;
    if (importDeclarations.length !== 0) {
        var lastImportIndex = body.indexOf(importDeclarations[importDeclarations.length - 1]);
        importDeclarationPaths = programPath
            .get("body." + lastImportIndex)
            .insertAfter(importDeclaration);
    }
    else {
        importDeclarationPaths = programPath.unshiftContainer("body", importDeclaration);
    }
    path.scope.registerDeclaration(importDeclarationPaths[0]);
    var newBinding = path.scope.getBinding(reference.name);
    return t.cloneDeep(newBinding.identifier);
};
