"use strict";
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var extractRules_1 = __importDefault(require("../extractRules"));
var types_1 = require("../types");
var styled = { test: String.raw };
it("Scopes top-level declarations", function () {
    var css = styled.test(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n    color: red;\n  "], ["\n    color: red;\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([
        {
            type: types_1.StyleType.Tuples,
            condition: null,
            styleTuples: [["color", "red"]],
            importedVariables: []
        }
    ]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Scopes multiple top-level declarations into one class", function () {
    var css = styled.test(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n    color: red;\n    border-left-color: green;\n  "], ["\n    color: red;\n    border-left-color: green;\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([
        {
            type: types_1.StyleType.Tuples,
            condition: null,
            styleTuples: [["color", "red"], ["border-left-color", "green"]],
            importedVariables: []
        }
    ]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Scopes boolean attribute selectors", function () {
    var css = styled.test(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n    &[@attribute] {\n      color: red;\n    }\n  "], ["\n    &[@attribute] {\n      color: red;\n    }\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({ attribute: { type: "bool" } });
    expect(rules.styles).toEqual([
        {
            type: types_1.StyleType.Tuples,
            condition: { selector: "&[cssta|attribute]", mediaQuery: null },
            styleTuples: [["color", "red"]],
            importedVariables: []
        }
    ]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Scopes string attribute selectors", function () {
    var css = styled.test(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n    &[@stringAttribute=\"red\"] {\n      color: red;\n    }\n  "], ["\n    &[@stringAttribute=\"red\"] {\n      color: red;\n    }\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({
        stringAttribute: { type: "oneOf", values: ["red"] }
    });
    expect(rules.styles).toEqual([
        {
            type: types_1.StyleType.Tuples,
            condition: {
                selector: '&[cssta|stringAttribute="red"]',
                mediaQuery: null
            },
            styleTuples: [["color", "red"]],
            importedVariables: []
        }
    ]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Scopes attribute selectors", function () {
    var css = styled.test(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n    &[@booleanValue1] {\n      color: red;\n    }\n\n    &[@booleanValue2] {\n      color: green;\n    }\n\n    &[@stringValue1=\"a\"] {\n      color: red;\n    }\n\n    &[@stringValue1=\"b\"] {\n      color: green;\n    }\n\n    &[@stringValue2=\"c\"] {\n      color: blue;\n    }\n  "], ["\n    &[@booleanValue1] {\n      color: red;\n    }\n\n    &[@booleanValue2] {\n      color: green;\n    }\n\n    &[@stringValue1=\"a\"] {\n      color: red;\n    }\n\n    &[@stringValue1=\"b\"] {\n      color: green;\n    }\n\n    &[@stringValue2=\"c\"] {\n      color: blue;\n    }\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({
        booleanValue1: { type: "bool" },
        booleanValue2: { type: "bool" },
        stringValue1: { type: "oneOf", values: ["a", "b"] },
        stringValue2: { type: "oneOf", values: ["c"] }
    });
    expect(rules.styles).toMatchInlineSnapshot("\n    Array [\n      Object {\n        \"condition\": Object {\n          \"mediaQuery\": null,\n          \"selector\": \"&[cssta|booleanValue1]\",\n        },\n        \"importedVariables\": Array [],\n        \"styleTuples\": Array [\n          Array [\n            \"color\",\n            \"red\",\n          ],\n        ],\n        \"type\": 0,\n      },\n      Object {\n        \"condition\": Object {\n          \"mediaQuery\": null,\n          \"selector\": \"&[cssta|booleanValue2]\",\n        },\n        \"importedVariables\": Array [],\n        \"styleTuples\": Array [\n          Array [\n            \"color\",\n            \"green\",\n          ],\n        ],\n        \"type\": 0,\n      },\n      Object {\n        \"condition\": Object {\n          \"mediaQuery\": null,\n          \"selector\": \"&[cssta|stringValue1=\\\"a\\\"]\",\n        },\n        \"importedVariables\": Array [],\n        \"styleTuples\": Array [\n          Array [\n            \"color\",\n            \"red\",\n          ],\n        ],\n        \"type\": 0,\n      },\n      Object {\n        \"condition\": Object {\n          \"mediaQuery\": null,\n          \"selector\": \"&[cssta|stringValue1=\\\"b\\\"]\",\n        },\n        \"importedVariables\": Array [],\n        \"styleTuples\": Array [\n          Array [\n            \"color\",\n            \"green\",\n          ],\n        ],\n        \"type\": 0,\n      },\n      Object {\n        \"condition\": Object {\n          \"mediaQuery\": null,\n          \"selector\": \"&[cssta|stringValue2=\\\"c\\\"]\",\n        },\n        \"importedVariables\": Array [],\n        \"styleTuples\": Array [\n          Array [\n            \"color\",\n            \"blue\",\n          ],\n        ],\n        \"type\": 0,\n      },\n    ]\n  ");
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Recognises variable declarations", function () {
    var css = styled.test(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n    --color: red;\n  "], ["\n    --color: red;\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([
        { condition: null, name: "color", value: "red", importedVariables: [] }
    ]);
});
it("Recognises variable imports", function () {
    var css = styled.test(templateObject_7 || (templateObject_7 = __makeTemplateObject(["\n    color: var(--color);\n  "], ["\n    color: var(--color);\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([
        {
            type: types_1.StyleType.Tuples,
            condition: null,
            styleTuples: [["color", "var(--color)"]],
            importedVariables: ["color"]
        }
    ]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Recognises multiple variable declarations", function () {
    var css = styled.test(templateObject_8 || (templateObject_8 = __makeTemplateObject(["\n    --color: red;\n    --color: blue;\n    --other: green;\n  "], ["\n    --color: red;\n    --color: blue;\n    --other: green;\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([
        { condition: null, name: "color", value: "red", importedVariables: [] },
        { condition: null, name: "color", value: "blue", importedVariables: [] },
        { condition: null, name: "other", value: "green", importedVariables: [] }
    ]);
});
it("Recognises multiple variable imports", function () {
    var css = styled.test(templateObject_9 || (templateObject_9 = __makeTemplateObject(["\n    margin: var(--large) var(--small);\n  "], ["\n    margin: var(--large) var(--small);\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([
        {
            type: types_1.StyleType.Tuples,
            condition: null,
            styleTuples: [["margin", "var(--large) var(--small)"]],
            importedVariables: ["large", "small"]
        }
    ]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Mixes variable and style declarations", function () {
    var css = styled.test(templateObject_10 || (templateObject_10 = __makeTemplateObject(["\n    --color: red;\n    color: var(--color);\n  "], ["\n    --color: red;\n    color: var(--color);\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([
        {
            type: types_1.StyleType.Tuples,
            condition: null,
            styleTuples: [["color", "var(--color)"]],
            importedVariables: ["color"]
        }
    ]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([
        { condition: null, name: "color", value: "red", importedVariables: [] }
    ]);
});
it("Recognises transitions", function () {
    var css = styled.test(templateObject_11 || (templateObject_11 = __makeTemplateObject(["\n    transition: color 1s linear;\n  "], ["\n    transition: color 1s linear;\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([]);
    expect(rules.transitions).toEqual([
        { condition: null, part: { _: "color 1s linear" }, importedVariables: [] }
    ]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Recognises transitions using long hand", function () {
    var css = styled.test(templateObject_12 || (templateObject_12 = __makeTemplateObject(["\n    transition-property: color;\n    transition-delay: 1s;\n    transition-duration: 2s;\n    transition-timing-function: linear;\n  "], ["\n    transition-property: color;\n    transition-delay: 1s;\n    transition-duration: 2s;\n    transition-timing-function: linear;\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([]);
    expect(rules.transitions).toEqual([
        {
            condition: null,
            part: {
                property: "color",
                delay: "1s",
                duration: "2s",
                timingFunction: "linear"
            },
            importedVariables: []
        }
    ]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Recognises multiple separate transitions", function () {
    var css = styled.test(templateObject_13 || (templateObject_13 = __makeTemplateObject(["\n    transition: color 1s linear, transform 2s ease-in-out;\n  "], ["\n    transition: color 1s linear, transform 2s ease-in-out;\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([]);
    expect(rules.transitions).toEqual([
        {
            condition: null,
            part: { _: "color 1s linear, transform 2s ease-in-out" },
            importedVariables: []
        }
    ]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Recognises multiple property transitions", function () {
    var css = styled.test(templateObject_14 || (templateObject_14 = __makeTemplateObject(["\n    transition: 1s linear;\n    transition-property: color, transform;\n  "], ["\n    transition: 1s linear;\n    transition-property: color, transform;\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([]);
    expect(rules.transitions).toEqual([
        {
            condition: null,
            part: { _: "1s linear", property: "color, transform" },
            importedVariables: []
        }
    ]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Overrides previous transition declarations when using shorthand", function () {
    var css = styled.test(templateObject_15 || (templateObject_15 = __makeTemplateObject(["\n    transition-property: color, transform;\n    transition-duration: 2s;\n    transition: 1s linear;\n  "], ["\n    transition-property: color, transform;\n    transition-duration: 2s;\n    transition: 1s linear;\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([]);
    expect(rules.transitions).toEqual([
        {
            condition: null,
            part: { _: "1s linear" },
            importedVariables: []
        }
    ]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Recognises multiple allows variables in transitions", function () {
    var css = styled.test(templateObject_16 || (templateObject_16 = __makeTemplateObject(["\n    transition: color var(--time) var(--easing);\n  "], ["\n    transition: color var(--time) var(--easing);\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([]);
    expect(rules.transitions).toEqual([
        {
            condition: null,
            part: { _: "color var(--time) var(--easing)" },
            importedVariables: ["time", "easing"]
        }
    ]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Recognises animations", function () {
    var css = styled.test(templateObject_17 || (templateObject_17 = __makeTemplateObject(["\n    animation: test 1s linear;\n  "], ["\n    animation: test 1s linear;\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([
        {
            condition: null,
            part: { _: "test 1s linear" },
            importedVariables: []
        }
    ]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Recognises animation long hands", function () {
    var css = styled.test(templateObject_18 || (templateObject_18 = __makeTemplateObject(["\n    animation-name: test;\n    animation-duration: 1s;\n    animation-delay: 2s;\n    animation-iteration-count: 3;\n    animation-timing-function: linear;\n  "], ["\n    animation-name: test;\n    animation-duration: 1s;\n    animation-delay: 2s;\n    animation-iteration-count: 3;\n    animation-timing-function: linear;\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([
        {
            condition: null,
            part: {
                name: "test",
                duration: "1s",
                delay: "2s",
                iterations: "3",
                timingFunction: "linear"
            },
            importedVariables: []
        }
    ]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Overrides previous animation declarations when using shorthand", function () {
    var css = styled.test(templateObject_19 || (templateObject_19 = __makeTemplateObject(["\n    animation-delay: 2s;\n    animation-iteration-count: 3;\n    animation-timing-function: linear;\n    animation: test 1s;\n  "], ["\n    animation-delay: 2s;\n    animation-iteration-count: 3;\n    animation-timing-function: linear;\n    animation: test 1s;\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([
        {
            condition: null,
            part: { _: "test 1s" },
            importedVariables: []
        }
    ]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Recognises keyframes", function () {
    var keyframes = extractRules_1["default"]("\n    @keyframes test {\n      from { opacity: 0 }\n      to { opacity: 1 }\n    }\n  ").keyframes;
    expect(keyframes).toEqual([
        {
            name: "test",
            sequence: [
                { time: 0, styleTuples: [["opacity", "0"]] },
                { time: 1, styleTuples: [["opacity", "1"]] }
            ],
            importedVariables: []
        }
    ]);
});
it("Recognises multiple keyframes", function () {
    var keyframes = extractRules_1["default"]("\n    @keyframes test1 {\n      from { opacity: 0 }\n      to { opacity: 1 }\n    }\n\n    @keyframes test2 {\n      from { opacity: 0 }\n      50% { opacity: 0.5 }\n      to { opacity: 1 }\n    }\n  ").keyframes;
    expect(keyframes).toEqual([
        {
            name: "test1",
            sequence: [
                { time: 0, styleTuples: [["opacity", "0"]] },
                { time: 1, styleTuples: [["opacity", "1"]] }
            ],
            importedVariables: []
        },
        {
            name: "test2",
            sequence: [
                { time: 0, styleTuples: [["opacity", "0"]] },
                { time: 0.5, styleTuples: [["opacity", "0.5"]] },
                { time: 1, styleTuples: [["opacity", "1"]] }
            ],
            importedVariables: []
        }
    ]);
});
it("Imports variables from keyframes", function () {
    var keyframes = extractRules_1["default"]("\n    @keyframes test {\n      from { color: var(--primary) }\n    }\n  ").keyframes;
    expect(keyframes[0].sequence).toEqual([
        {
            time: 0,
            styleTuples: [["color", "var(--primary)"]]
        }
    ]);
    expect(keyframes[0].importedVariables).toEqual(["primary"]);
});
it("Recognises media queries for top-level declarations", function () {
    var css = styled.test(templateObject_20 || (templateObject_20 = __makeTemplateObject(["\n    @media (min-width: 500px) {\n      color: red;\n    }\n  "], ["\n    @media (min-width: 500px) {\n      color: red;\n    }\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([
        {
            type: types_1.StyleType.Tuples,
            condition: { selector: "&", mediaQuery: "(min-width: 500px)" },
            styleTuples: [["color", "red"]],
            importedVariables: []
        }
    ]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Recognises media queries for nested rules", function () {
    var css = styled.test(templateObject_21 || (templateObject_21 = __makeTemplateObject(["\n    @media (min-width: 500px) {\n      &[@prop] {\n        color: red;\n      }\n    }\n  "], ["\n    @media (min-width: 500px) {\n      &[@prop] {\n        color: red;\n      }\n    }\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({ prop: { type: "bool" } });
    expect(rules.styles).toEqual([
        {
            type: types_1.StyleType.Tuples,
            condition: {
                selector: "&[cssta|prop]",
                mediaQuery: "(min-width: 500px)"
            },
            styleTuples: [["color", "red"]],
            importedVariables: []
        }
    ]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Combines all options together", function () {
    var css = styled.test(templateObject_22 || (templateObject_22 = __makeTemplateObject(["\n    color: red;\n\n    &[@boolProp] {\n      color: green;\n      animation: var(--timing) someAnimation ease-in;\n    }\n\n    &[@someStringProp=\"1\"] {\n      transition: 3s;\n      --someProp: 5px;\n    }\n\n    @keyframes someAnimation {\n      from {\n        opacity: 0;\n      }\n      to {\n        opacity: 1;\n      }\n    }\n  "], ["\n    color: red;\n\n    &[@boolProp] {\n      color: green;\n      animation: var(--timing) someAnimation ease-in;\n    }\n\n    &[@someStringProp=\"1\"] {\n      transition: 3s;\n      --someProp: 5px;\n    }\n\n    @keyframes someAnimation {\n      from {\n        opacity: 0;\n      }\n      to {\n        opacity: 1;\n      }\n    }\n  "])));
    expect(extractRules_1["default"](css)).toMatchInlineSnapshot("\n    Object {\n      \"animations\": Array [\n        Object {\n          \"condition\": Object {\n            \"mediaQuery\": null,\n            \"selector\": \"&[cssta|boolProp]\",\n          },\n          \"importedVariables\": Array [\n            \"timing\",\n          ],\n          \"part\": Object {\n            \"_\": \"var(--timing) someAnimation ease-in\",\n          },\n        },\n      ],\n      \"exportedVariables\": Array [\n        Object {\n          \"condition\": Object {\n            \"mediaQuery\": null,\n            \"selector\": \"&[cssta|someStringProp=\\\"1\\\"]\",\n          },\n          \"importedVariables\": Array [],\n          \"name\": \"someProp\",\n          \"value\": \"5px\",\n        },\n      ],\n      \"keyframes\": Array [\n        Object {\n          \"importedVariables\": Array [],\n          \"name\": \"someAnimation\",\n          \"sequence\": Array [\n            Object {\n              \"styleTuples\": Array [\n                Array [\n                  \"opacity\",\n                  \"0\",\n                ],\n              ],\n              \"time\": 0,\n            },\n            Object {\n              \"styleTuples\": Array [\n                Array [\n                  \"opacity\",\n                  \"1\",\n                ],\n              ],\n              \"time\": 1,\n            },\n          ],\n        },\n      ],\n      \"propTypes\": Object {\n        \"boolProp\": Object {\n          \"type\": \"bool\",\n        },\n        \"someStringProp\": Object {\n          \"type\": \"oneOf\",\n          \"values\": Array [\n            \"1\",\n          ],\n        },\n      },\n      \"styles\": Array [\n        Object {\n          \"condition\": null,\n          \"importedVariables\": Array [],\n          \"styleTuples\": Array [\n            Array [\n              \"color\",\n              \"red\",\n            ],\n          ],\n          \"type\": 0,\n        },\n        Object {\n          \"condition\": Object {\n            \"mediaQuery\": null,\n            \"selector\": \"&[cssta|boolProp]\",\n          },\n          \"importedVariables\": Array [],\n          \"styleTuples\": Array [\n            Array [\n              \"color\",\n              \"green\",\n            ],\n          ],\n          \"type\": 0,\n        },\n      ],\n      \"transitions\": Array [\n        Object {\n          \"condition\": Object {\n            \"mediaQuery\": null,\n            \"selector\": \"&[cssta|someStringProp=\\\"1\\\"]\",\n          },\n          \"importedVariables\": Array [],\n          \"part\": Object {\n            \"_\": \"3s\",\n          },\n        },\n      ],\n    }\n  ");
});
it("Handles mixins", function () {
    var css = styled.test(templateObject_23 || (templateObject_23 = __makeTemplateObject(["\n    @include someMixin;\n  "], ["\n    @include someMixin;\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([
        {
            type: types_1.StyleType.Mixin,
            condition: null,
            substitution: "someMixin"
        }
    ]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Handles conditional mixins", function () {
    var css = styled.test(templateObject_24 || (templateObject_24 = __makeTemplateObject(["\n    &[@cond] {\n      @include someMixin;\n    }\n  "], ["\n    &[@cond] {\n      @include someMixin;\n    }\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({ cond: { type: "bool" } });
    expect(rules.styles).toEqual([
        {
            type: types_1.StyleType.Mixin,
            condition: { selector: "&[cssta|cond]", mediaQuery: null },
            substitution: "someMixin"
        }
    ]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Handles mixins in media queries", function () {
    var css = styled.test(templateObject_25 || (templateObject_25 = __makeTemplateObject(["\n    @media (min-width: 500px) {\n      @include someMixin;\n    }\n  "], ["\n    @media (min-width: 500px) {\n      @include someMixin;\n    }\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([
        {
            type: types_1.StyleType.Mixin,
            condition: { selector: "&", mediaQuery: "(min-width: 500px)" },
            substitution: "someMixin"
        }
    ]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Handles conditional mixins in media queries", function () {
    var css = styled.test(templateObject_26 || (templateObject_26 = __makeTemplateObject(["\n    @media (min-width: 500px) {\n      &[@cond] {\n        @include someMixin;\n      }\n    }\n  "], ["\n    @media (min-width: 500px) {\n      &[@cond] {\n        @include someMixin;\n      }\n    }\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({ cond: { type: "bool" } });
    expect(rules.styles).toEqual([
        {
            type: types_1.StyleType.Mixin,
            condition: {
                selector: "&[cssta|cond]",
                mediaQuery: "(min-width: 500px)"
            },
            substitution: "someMixin"
        }
    ]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
it("Handles mixins within style tuples", function () {
    var css = styled.test(templateObject_27 || (templateObject_27 = __makeTemplateObject(["\n    top: 10px;\n    right: 10px;\n    @include someMixin;\n    bottom: 10px;\n    left: var(--left);\n  "], ["\n    top: 10px;\n    right: 10px;\n    @include someMixin;\n    bottom: 10px;\n    left: var(--left);\n  "])));
    var rules = extractRules_1["default"](css);
    expect(rules.propTypes).toEqual({});
    expect(rules.styles).toEqual([
        {
            type: types_1.StyleType.Tuples,
            condition: null,
            styleTuples: [["top", "10px"], ["right", "10px"]],
            importedVariables: []
        },
        {
            type: types_1.StyleType.Mixin,
            condition: null,
            substitution: "someMixin"
        },
        {
            type: types_1.StyleType.Tuples,
            condition: null,
            styleTuples: [["bottom", "10px"], ["left", "var(--left)"]],
            importedVariables: ["left"]
        }
    ]);
    expect(rules.transitions).toEqual([]);
    expect(rules.animations).toEqual([]);
    expect(rules.keyframes).toEqual([]);
    expect(rules.exportedVariables).toEqual([]);
});
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7, templateObject_8, templateObject_9, templateObject_10, templateObject_11, templateObject_12, templateObject_13, templateObject_14, templateObject_15, templateObject_16, templateObject_17, templateObject_18, templateObject_19, templateObject_20, templateObject_21, templateObject_22, templateObject_23, templateObject_24, templateObject_25, templateObject_26, templateObject_27;
