"use strict";
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var postcss_1 = __importDefault(require("postcss"));
var getRoot_1 = __importDefault(require("../getRoot"));
var styled = { test: String.raw };
var stringifyRoot = function (root) {
    root.cleanRaws();
    root.walkRules(function (node) {
        node.raws.semicolon = true;
    });
    return root.toString();
};
var runTestFor = function (inputCss, expectedCss, expectedPropTypes, allowCombinators) {
    if (expectedCss === void 0) { expectedCss = inputCss.replace(/(\[\s*)@(\w)/g, "$1cssta|$2"); }
    if (expectedPropTypes === void 0) { expectedPropTypes = {}; }
    if (allowCombinators === void 0) { allowCombinators = false; }
    var expectedRoot = postcss_1["default"].parse(expectedCss);
    var _a = getRoot_1["default"](inputCss, allowCombinators), actualRoot = _a.root, actualPropTypes = _a.propTypes;
    expect(stringifyRoot(actualRoot)).toBe(stringifyRoot(expectedRoot));
    expect(actualPropTypes).toEqual(expectedPropTypes);
};
var shouldThrow = function (inputCss) {
    expect(function () { return getRoot_1["default"](inputCss); }).toThrow();
};
it("Nests top-level declarations", function () {
    runTestFor(styled.test(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n      color: red;\n    "], ["\n      color: red;\n    "]))), styled.test(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n      & {\n        color: red;\n      }\n    "], ["\n      & {\n        color: red;\n      }\n    "]))));
});
it("Nests top-level mixins", function () {
    runTestFor(styled.test(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n      @include someMixin;\n    "], ["\n      @include someMixin;\n    "]))), styled.test(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n      & {\n        @include someMixin;\n      }\n    "], ["\n      & {\n        @include someMixin;\n      }\n    "]))));
});
it("Nests within @-rules", function () {
    runTestFor(styled.test(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n      @supports (color: red) {\n        color: red;\n      }\n\n      @media (screen) {\n        color: green;\n      }\n    "], ["\n      @supports (color: red) {\n        color: red;\n      }\n\n      @media (screen) {\n        color: green;\n      }\n    "]))), styled.test(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n      @supports (color: red) {\n        & {\n          color: red;\n        }\n      }\n\n      @media (screen) {\n        & {\n          color: green;\n        }\n      }\n    "], ["\n      @supports (color: red) {\n        & {\n          color: red;\n        }\n      }\n\n      @media (screen) {\n        & {\n          color: green;\n        }\n      }\n    "]))));
});
it("Does not re-nest nested rules", function () {
    runTestFor(styled.test(templateObject_7 || (templateObject_7 = __makeTemplateObject(["\n    & {\n      color: red;\n    }\n  "], ["\n    & {\n      color: red;\n    }\n  "]))));
});
it("Requires nesting", function () {
    expect(function () {
        getRoot_1["default"](":hover {}");
    }).toThrow();
    expect(function () {
        getRoot_1["default"]("[@attribute] {}");
    }).toThrow();
});
it("Generates prop type for bool attributes", function () {
    runTestFor(styled.test(templateObject_8 || (templateObject_8 = __makeTemplateObject(["\n      &[@attribute] {\n        color: red;\n      }\n    "], ["\n      &[@attribute] {\n        color: red;\n      }\n    "]))), undefined, { attribute: { type: "bool" } });
});
it("Generates prop type for string attributes", function () {
    runTestFor(styled.test(templateObject_9 || (templateObject_9 = __makeTemplateObject(["\n      &[@attribute=\"1\"] {\n        color: red;\n      }\n\n      &[@attribute=\"2\"] {\n        color: red;\n      }\n    "], ["\n      &[@attribute=\"1\"] {\n        color: red;\n      }\n\n      &[@attribute=\"2\"] {\n        color: red;\n      }\n    "]))), undefined, { attribute: { type: "oneOf", values: ["1", "2"] } });
});
it("Generates multile prop types for multiple attributes", function () {
    runTestFor(styled.test(templateObject_10 || (templateObject_10 = __makeTemplateObject(["\n      &[@boolAttribute] {\n        color: red;\n      }\n\n      &[@stringAttribute=\"1\"] {\n        color: red;\n      }\n\n      &[@stringAttribute=\"2\"] {\n        color: red;\n      }\n    "], ["\n      &[@boolAttribute] {\n        color: red;\n      }\n\n      &[@stringAttribute=\"1\"] {\n        color: red;\n      }\n\n      &[@stringAttribute=\"2\"] {\n        color: red;\n      }\n    "]))), undefined, {
        boolAttribute: { type: "bool" },
        stringAttribute: { type: "oneOf", values: ["1", "2"] }
    });
});
it("Only defines values for string attribute once", function () {
    runTestFor(styled.test(templateObject_11 || (templateObject_11 = __makeTemplateObject(["\n      &[@attribute=\"1\"] {\n        color: red;\n      }\n\n      &[@attribute=\"1\"] {\n        color: red;\n      }\n    "], ["\n      &[@attribute=\"1\"] {\n        color: red;\n      }\n\n      &[@attribute=\"1\"] {\n        color: red;\n      }\n    "]))), undefined, { attribute: { type: "oneOf", values: ["1"] } });
});
it("Does not nest declarations within keyframes", function () {
    runTestFor(styled.test(templateObject_12 || (templateObject_12 = __makeTemplateObject(["\n    @keyframes test {\n      color: red;\n    }\n  "], ["\n    @keyframes test {\n      color: red;\n    }\n  "]))));
});
it("Does not nest nested rules", function () {
    runTestFor(styled.test(templateObject_13 || (templateObject_13 = __makeTemplateObject(["\n    & {\n      color: red;\n    }\n  "], ["\n    & {\n      color: red;\n    }\n  "]))));
});
it("Optionally allows combinators scoping with &", function () {
    runTestFor(styled.test(templateObject_14 || (templateObject_14 = __makeTemplateObject(["\n      :fullscreen & {\n        color: red;\n      }\n    "], ["\n      :fullscreen & {\n        color: red;\n      }\n    "]))), undefined, undefined, true);
});
it("Optionally allows combinators scoping with prop selectors", function () {
    runTestFor(styled.test(templateObject_15 || (templateObject_15 = __makeTemplateObject(["\n      :fullscreen &[@attribute] {\n        color: red;\n      }\n    "], ["\n      :fullscreen &[@attribute] {\n        color: red;\n      }\n    "]))), undefined, { attribute: { type: "bool" } }, true);
});
it("When allowing combinators, prop selectors must be tied to an &", function () {
    expect(function () {
        getRoot_1["default"](styled.test(templateObject_16 || (templateObject_16 = __makeTemplateObject(["\n        & [@prop] {\n        }\n      "], ["\n        & [@prop] {\n        }\n      "]))));
    }).toThrow();
    expect(function () {
        getRoot_1["default"](styled.test(templateObject_17 || (templateObject_17 = __makeTemplateObject(["\n        :not(&[@prop]) {\n        }\n      "], ["\n        :not(&[@prop]) {\n        }\n      "]))));
    }).toThrow();
});
it("Does not allow combinators by default", function () {
    shouldThrow(styled.test(templateObject_18 || (templateObject_18 = __makeTemplateObject(["\n    & & {\n      color: red;\n    }\n  "], ["\n    & & {\n      color: red;\n    }\n  "]))));
});
it("Does not allow combinators after scoping with &", function () {
    shouldThrow(styled.test(templateObject_19 || (templateObject_19 = __makeTemplateObject(["\n    & :fullscreen {\n      color: red;\n    }\n  "], ["\n    & :fullscreen {\n      color: red;\n    }\n  "]))));
});
it("Does not allow combinators after scoping with prop selectors", function () {
    shouldThrow(styled.test(templateObject_20 || (templateObject_20 = __makeTemplateObject(["\n    &[@attribute] :fullscreen {\n      color: red;\n    }\n  "], ["\n    &[@attribute] :fullscreen {\n      color: red;\n    }\n  "]))));
});
it("Does not allow case-insensitive attributes", function () {
    shouldThrow(styled.test(templateObject_21 || (templateObject_21 = __makeTemplateObject(["\n    &[@attribute=\"value\" i] {\n      color: red;\n    }\n  "], ["\n    &[@attribute=\"value\" i] {\n      color: red;\n    }\n  "]))));
});
it("Only allows = as operator in attribute", function () {
    shouldThrow(styled.test(templateObject_22 || (templateObject_22 = __makeTemplateObject(["\n    &[@attribute~=\"value\"] {\n      color: red;\n    }\n  "], ["\n    &[@attribute~=\"value\"] {\n      color: red;\n    }\n  "]))));
});
it('does not allow attributes to be called "component"', function () {
    shouldThrow(styled.test(templateObject_23 || (templateObject_23 = __makeTemplateObject(["\n    &[@component] {\n      color: red;\n    }\n  "], ["\n    &[@component] {\n      color: red;\n    }\n  "]))));
});
it("Enforces consistent prop types", function () {
    shouldThrow(styled.test(templateObject_24 || (templateObject_24 = __makeTemplateObject(["\n    &[@mixedAttribute] {\n      color: red;\n    }\n\n    &[@mixedAttribute=\"value\"] {\n      color: red;\n    }\n  "], ["\n    &[@mixedAttribute] {\n      color: red;\n    }\n\n    &[@mixedAttribute=\"value\"] {\n      color: red;\n    }\n  "]))));
});
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7, templateObject_8, templateObject_9, templateObject_10, templateObject_11, templateObject_12, templateObject_13, templateObject_14, templateObject_15, templateObject_16, templateObject_17, templateObject_18, templateObject_19, templateObject_20, templateObject_21, templateObject_22, templateObject_23, templateObject_24;
