"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var postcss_1 = __importDefault(require("postcss"));
var cssRegExp_1 = require("../../runtime/cssRegExp");
exports.parseGlobals = function (input, _a) {
    var _b = (_a === void 0 ? {} : _a).globalVarsOnly, globalVarsOnly = _b === void 0 ? false : _b;
    if (input == null) {
        return { vars: new Map(), conditions: [], globalVarsOnly: globalVarsOnly };
    }
    else if (typeof input === "object") {
        return {
            vars: new Map(Object.keys(input).map(function (v) { return [v, new Set([0])]; })),
            conditions: [
                { query: undefined, values: new Map(Object.entries(input)) }
            ],
            globalVarsOnly: globalVarsOnly
        };
    }
    var root = postcss_1["default"].parse(input);
    var atRules = [];
    root.walkAtRules("media", function (atRule) { return atRules.push(atRule); });
    var vars = new Map();
    var conditions = __spreadArrays([
        { query: undefined, values: new Map() }
    ], atRules.map(function (atRule) { return ({
        query: atRule.params,
        values: new Map()
    }); }));
    root.walkDecls(function (decl) {
        var prop = decl.prop.slice("--".length);
        var conditionIndex = 0;
        if (decl.parent.type === "atrule" && decl.parent.name === "media") {
            conditionIndex = atRules.indexOf(decl.parent) + 1;
        }
        conditions[conditionIndex].values.set(prop, decl.value);
        if (!vars.has(prop))
            vars.set(prop, new Set());
        vars.get(prop).add(conditionIndex);
    });
    return { vars: vars, conditions: conditions, globalVarsOnly: globalVarsOnly };
};
exports.applyGlobals = function (root, globals) {
    root.walkRules(function (rule) {
        var conditionProps = new Map();
        rule.walkDecls(function (decl) {
            Array.from(decl.value.matchAll(cssRegExp_1.varRegExp)).forEach(function (match) {
                var conditions = globals.vars.get(match[1]);
                if (conditions == null)
                    return;
                conditions.forEach(function (cond) {
                    conditionProps.set(cond, decl.prop);
                });
            });
        });
        // Sorted backwards
        // We add the at rules directly after the rule, so the last needs to be added first
        var conditionIndicies = Array.from(conditionProps.keys()).sort(function (a, b) { return b - a; });
        conditionIndicies.forEach(function (index) {
            var _a = globals.conditions[index], query = _a.query, values = _a.values;
            var ruleCopy = rule.clone();
            var didEdit = false;
            var replaceVars = function (value) {
                return value.replace(cssRegExp_1.varRegExp, function (fullMatch, variable, fallback) {
                    didEdit = true;
                    if (values.has(variable)) {
                        return values.get(variable);
                    }
                    else if (fallback) {
                        return fallback;
                    }
                    else if (!globals.globalVarsOnly) {
                        return fullMatch;
                    }
                    else {
                        throw new Error("Found variable \"" + variable + "\". This was not defined in the globals, and `globalVarsOnly` is enabled. See line with `var(--" + variable + ")`");
                    }
                });
            };
            ruleCopy.walkDecls(function (decl) {
                decl.value = replaceVars(decl.value);
            });
            if (!didEdit)
                return;
            if (query === undefined) {
                rule.replaceWith(ruleCopy);
            }
            else if (rule.parent.type === "atrule") {
                var params = rule.parent.params
                    .split(",")
                    .map(function (rule) { return rule + " and " + query; })
                    .join(",");
                var atRule = postcss_1["default"].atRule({ name: "media", params: params });
                atRule.append(ruleCopy);
                rule.parent.parent.insertAfter(rule.parent, atRule);
            }
            else {
                /*
                We do actually have to clone the whole rule for cases like
        
                border: 0px solid var(--color);
                border-top: 1px;
                border-bottom: 1px;
        
                Otherwise we'd reset the top and bottom width
        
                It's also more performant to copy the whole style, as a later stage
                optimises for this exact case
                */
                var atRule = postcss_1["default"].atRule({ name: "media", params: query });
                atRule.append(ruleCopy);
                rule.parent.insertAfter(rule, atRule);
            }
        });
    });
};
exports["default"] = (function (root, options) {
    return exports.applyGlobals(root, exports.parseGlobals(options.globals, options));
});
