"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
/* eslint-disable no-param-reassign */
var postcss_1 = __importDefault(require("postcss"));
var postcss_selector_parser_1 = __importDefault(require("postcss-selector-parser"));
var util_1 = require("./util");
// Don't use root.each, because when we remove nodes, we'll skip them
var iterateChildren = function (root, callback) {
    var iterate = function (node) {
        if (!node)
            return;
        var nextNode = node.next();
        callback(node);
        iterate(nextNode);
    };
    iterate(root.first);
};
var nestInAmpersandSelector = function (node) {
    var prevNode = node.prev();
    if (prevNode && prevNode.type === "rule" && prevNode.selector === "&") {
        prevNode.append(node);
    }
    else {
        var ruleNode = postcss_1["default"].rule({ selector: "&" });
        node.before(ruleNode);
        ruleNode.append(node);
    }
};
var nestNode = function (node) {
    switch (node.type) {
        case "decl": {
            nestInAmpersandSelector(node);
            break;
        }
        case "atrule": {
            if (node.name === "include") {
                nestInAmpersandSelector(node);
            }
            else if (!util_1.keyframesRegExp.test(node.name)) {
                iterateChildren(node, nestNode);
            }
            break;
        }
        default:
            break;
    }
};
exports["default"] = (function (inputCss, allowCombinators) {
    if (allowCombinators === void 0) { allowCombinators = false; }
    var transformedInput = inputCss.replace(/(\[\s*)@(\w)/g, "$1cssta|$2");
    var root = postcss_1["default"].parse(transformedInput);
    iterateChildren(root, nestNode);
    var propTypes = {};
    var validateAndTransformSelectors = postcss_selector_parser_1["default"](function (container) {
        container.each(function (selector) {
            if (selector.type !== "selector") {
                throw new Error("Expected selector");
            }
            var didScopeNode = false;
            selector.walk(function (node) {
                if (node.type === "combinator" && !allowCombinators) {
                    throw new Error("Invalid use of combinator in selector");
                }
                else if (node.type === "nesting") {
                    didScopeNode = true;
                }
                else if (node.type === "attribute" && node.ns === "cssta") {
                    var isInNot = node.parent.parent.type === "pseudo" &&
                        node.parent.parent.value === ":not";
                    var nodeThatMustBeTiedToNesting = isInNot
                        ? node.parent.parent.parent
                        : node.parent;
                    var isTiedToNesting = nodeThatMustBeTiedToNesting.nodes.some(function (child) { return child.type === "nesting"; });
                    if (!isTiedToNesting) {
                        throw new Error('Prop selectors ([@prop]) must be scoped using an "&"');
                    }
                    var prop = node.attribute.trim();
                    var propType = node.value ? "oneOf" : "bool";
                    if (propType === "oneOf" && node.operator !== "=") {
                        throw new Error("You cannot use operator " + node.operator + " in a prop selector");
                    }
                    if (propType === "oneOf" && node.insensitive) {
                        throw new Error("You cannot use case-insensitive prop selectors");
                    }
                    if (prop === "component") {
                        throw new Error('You cannot name an prop "component"');
                    }
                    if (!(prop in propTypes)) {
                        propTypes[prop] = { type: propType };
                    }
                    else if (propTypes[prop].type !== propType) {
                        throw new Error("Prop \"" + prop + "\" defined as both bool and a string");
                    }
                    if (propType === "oneOf") {
                        var value = node.value.trim();
                        var nextValues = new Set(propTypes[prop].values || []);
                        nextValues.add(value);
                        propTypes[prop].values = Array.from(nextValues);
                    }
                }
            });
            if (!didScopeNode) {
                throw new Error('You must use "&" in every selector');
            }
        });
    });
    root.walkRules(function (rule) {
        if (!util_1.isDirectChildOfKeyframes(rule)) {
            rule.selector = validateAndTransformSelectors.processSync(rule.selector);
        }
    });
    return { root: root, propTypes: propTypes };
});
