"use strict";
exports.__esModule = true;
var react_native_1 = require("react-native");
var animationUtil_1 = require("../animationUtil");
it("Inteprolates string values", function () {
    var animation = new react_native_1.Animated.Value(0);
    var interpolated = animationUtil_1.interpolateValue([0, 1], ["red", "green"], animation, false);
    expect(interpolated).toEqual({
        type: "interpolate",
        value: 0,
        options: { inputRange: [0, 1], outputRange: ["red", "green"] }
    });
});
it("Inteprolates number values with interpolate numbers = false", function () {
    var animation = new react_native_1.Animated.Value(0);
    var interpolated = animationUtil_1.interpolateValue([0, 1], [5, 10], animation, false);
    expect(interpolated).toEqual({
        type: "interpolate",
        value: 0,
        options: { inputRange: [0, 1], outputRange: [5, 10] }
    });
});
it("Inteprolates number values with interpolate numbers = true", function () {
    var animation = new react_native_1.Animated.Value(0);
    var interpolated = animationUtil_1.interpolateValue([0, 1], [5, 10], animation, true);
    expect(interpolated).toEqual({ type: "value", value: 0 });
});
it("Inteprolates transforms", function () {
    var animation = new react_native_1.Animated.Value(0);
    var interpolated = animationUtil_1.interpolateValue([0, 1], [
        [{ translateY: 5 }, { rotate: "30deg" }],
        [{ translateY: 10 }, { rotate: "45deg" }]
    ], animation, false);
    expect(interpolated).toEqual([
        {
            translateY: {
                type: "interpolate",
                value: 0,
                options: { inputRange: [0, 1], outputRange: [5, 10] }
            }
        },
        {
            rotate: {
                type: "interpolate",
                value: 0,
                options: { inputRange: [0, 1], outputRange: ["30deg", "45deg"] }
            }
        }
    ]);
});
it("Logs console error when animated transform nodes don't match", function () {
    var consoleSpy = jest.spyOn(console, "error").mockImplementation(function () { });
    var animation = new react_native_1.Animated.Value(0);
    animationUtil_1.interpolateValue([0, 1], [
        [{ translateY: 5 }, { rotate: "30deg" }],
        [{ translateY: 10 }, { rotate: "45deg" }, { scale: 3 }]
    ], animation, false);
    expect(consoleSpy).toBeCalledWith("Expected transforms to have same shape between transitions");
    consoleSpy.mockRestore();
});
it("Doesn't crash when transform nodes don't match", function () {
    var consoleSpy = jest.spyOn(console, "error").mockImplementation(function () { });
    var animation = new react_native_1.Animated.Value(0);
    expect(function () {
        animationUtil_1.interpolateValue([0, 1], [
            [{ translateY: 10 }, { rotate: "45deg" }, { scale: 3 }],
            [{ translateY: 5 }, { rotate: "30deg" }]
        ], animation, false);
    }).not.toThrow();
    consoleSpy.mockRestore();
});
