"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var resolveVariableDependencies_1 = __importDefault(require("../resolveVariableDependencies"));
it("Resolves a single variable", function () {
    var actualVariables = resolveVariableDependencies_1["default"]({ color: "red" }, {});
    expect(actualVariables).toEqual({ color: "red" });
});
it("Resolves a variable refercing a higher scope", function () {
    var actualVariables = resolveVariableDependencies_1["default"]({ primary: "red" }, { color: "var(--primary)" });
    expect(actualVariables).toEqual({ primary: "red", color: "red" });
});
it("Resolves a variable refercing the current scope", function () {
    var actualVariables = resolveVariableDependencies_1["default"]({}, { color: "var(--primary)", primary: "red" });
    expect(actualVariables).toEqual({ color: "red", primary: "red" });
});
it("Has the current scope override higher scopes", function () {
    var actualVariables = resolveVariableDependencies_1["default"]({ primary: "blue" }, { color: "var(--primary)", primary: "red" });
    expect(actualVariables).toEqual({ color: "red", primary: "red" });
});
it("Allows defaults", function () {
    var actualVariables = resolveVariableDependencies_1["default"]({ color: "var(--primary, blue)" }, {});
    expect(actualVariables).toEqual({ color: "blue" });
});
it("Throws on allow circular dependencies", function () {
    expect(function () {
        resolveVariableDependencies_1["default"]({ color: "var(--primary)", primary: "var(--color)" }, {});
    }).toThrow();
});
