"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var react_1 = __importDefault(require("react"));
var react_native_1 = require("../__mocks__/react-native");
var react_test_renderer_1 = require("react-test-renderer");
var useAnimation_1 = __importDefault(require("../useAnimation"));
it("Fires animation on creation", function () {
    var keyframes = {
        test: [
            { time: 0, style: { color: "red" } },
            { time: 1, style: { color: "blue" } }
        ]
    };
    var animation = {
        delay: 0,
        duration: 1000,
        iterations: 1,
        name: "test",
        timingFunction: "linear"
    };
    var startSpy = jest.spyOn(react_native_1.AnimatedNode.prototype, "start");
    var setValueSpy = jest.spyOn(react_native_1.AnimatedNode.prototype, "setValue");
    var animationStyle;
    var Test = function () {
        var _a;
        _a = useAnimation_1["default"](keyframes, animation, null), animationStyle = _a[1];
        return null;
    };
    var instance = react_test_renderer_1.create(react_1["default"].createElement(Test));
    expect(animationStyle.color).toEqual({
        type: "interpolate",
        value: 0,
        options: { inputRange: [0, 1], outputRange: ["red", "blue"] }
    });
    expect(startSpy).toHaveReturnedWith({
        type: "parallel",
        value: [
            {
                type: "timing",
                value: { type: "value", value: 0 },
                options: { delay: 0, duration: 1000, easing: "linear", toValue: 1 }
            }
        ]
    });
    expect(setValueSpy).toHaveBeenCalledWith(0);
    expect(setValueSpy).toHaveReturnedWith({ type: "value", value: 0 });
    instance.unmount();
    startSpy.mockRestore();
    setValueSpy.mockRestore();
});
it("Handles no animation", function () {
    var keyframes = {
        test: [
            { time: 0, style: { color: "red" } },
            { time: 1, style: { color: "blue" } }
        ]
    };
    var startSpy = jest.spyOn(react_native_1.AnimatedNode.prototype, "start");
    var setValueSpy = jest.spyOn(react_native_1.AnimatedNode.prototype, "setValue");
    var style;
    var Test = function () {
        style = useAnimation_1["default"](keyframes, null, null);
        return null;
    };
    var instance = react_test_renderer_1.create(react_1["default"].createElement(Test));
    expect(style).toBe(null);
    expect(startSpy).not.toHaveBeenCalled();
    expect(setValueSpy).not.toHaveBeenCalled();
    instance.unmount();
    startSpy.mockRestore();
    setValueSpy.mockRestore();
});
it("Handles going from no animation to an animation", function () {
    var keyframes = {
        test: [
            { time: 0, style: { color: "red" } },
            { time: 1, style: { color: "blue" } }
        ]
    };
    var animation = {
        delay: 0,
        duration: 1000,
        iterations: 1,
        name: "test",
        timingFunction: "linear"
    };
    var startSpy = jest.spyOn(react_native_1.AnimatedNode.prototype, "start");
    var setValueSpy = jest.spyOn(react_native_1.AnimatedNode.prototype, "setValue");
    var style;
    var Test = function (_a) {
        var animation = _a.animation;
        style = useAnimation_1["default"](keyframes, animation, null);
        return null;
    };
    var instance = react_test_renderer_1.create(react_1["default"].createElement(Test));
    expect(style).toBe(null);
    expect(startSpy).not.toHaveBeenCalled();
    expect(setValueSpy).not.toHaveBeenCalled();
    instance.update(react_1["default"].createElement(Test, { animation: animation }));
    expect(style[1].color).toEqual({
        type: "interpolate",
        value: 0,
        options: { inputRange: [0, 1], outputRange: ["red", "blue"] }
    });
    expect(startSpy).toHaveReturnedWith({
        type: "parallel",
        value: [
            {
                type: "timing",
                value: { type: "value", value: 0 },
                options: { delay: 0, duration: 1000, easing: "linear", toValue: 1 }
            }
        ]
    });
    expect(setValueSpy).toHaveBeenCalledWith(0);
    expect(setValueSpy).toHaveReturnedWith({ type: "value", value: 0 });
    instance.unmount();
    startSpy.mockRestore();
    setValueSpy.mockRestore();
});
it("Handles changing animation to an animation", function () {
    var keyframes = {
        test: [
            { time: 0, style: { color: "red" } },
            { time: 1, style: { color: "blue" } }
        ],
        other: [
            { time: 0, style: { color: "orange" } },
            { time: 1, style: { color: "purple" } }
        ]
    };
    var animation1 = {
        delay: 0,
        duration: 1000,
        iterations: 1,
        name: "test",
        timingFunction: "linear"
    };
    var animation2 = {
        delay: 0,
        duration: 2000,
        iterations: 1,
        name: "other",
        timingFunction: "linear"
    };
    var startSpy = jest.spyOn(react_native_1.AnimatedNode.prototype, "start");
    var setValueSpy = jest.spyOn(react_native_1.AnimatedNode.prototype, "setValue");
    var animationStyle;
    var Test = function (_a) {
        var _b;
        var animation = _a.animation;
        _b = useAnimation_1["default"](keyframes, animation, null), animationStyle = _b[1];
        return null;
    };
    var instance = react_test_renderer_1.create(react_1["default"].createElement(Test, { animation: animation1 }));
    expect(startSpy).toHaveBeenCalledTimes(1);
    expect(animationStyle.color).toEqual({
        type: "interpolate",
        value: 0,
        options: { inputRange: [0, 1], outputRange: ["red", "blue"] }
    });
    expect(startSpy).toHaveLastReturnedWith({
        type: "parallel",
        value: [
            {
                type: "timing",
                value: { type: "value", value: 0 },
                options: { delay: 0, duration: 1000, easing: "linear", toValue: 1 }
            }
        ]
    });
    expect(setValueSpy).toHaveBeenLastCalledWith(0);
    expect(setValueSpy).toHaveLastReturnedWith({ type: "value", value: 0 });
    instance.update(react_1["default"].createElement(Test, { animation: animation2 }));
    expect(startSpy).toHaveBeenCalledTimes(2);
    expect(animationStyle.color).toEqual({
        type: "interpolate",
        value: 0,
        options: { inputRange: [0, 1], outputRange: ["orange", "purple"] }
    });
    expect(startSpy).toHaveLastReturnedWith({
        type: "parallel",
        value: [
            {
                type: "timing",
                value: { type: "value", value: 0 },
                options: { delay: 0, duration: 2000, easing: "linear", toValue: 1 }
            }
        ]
    });
    expect(setValueSpy).toHaveBeenLastCalledWith(0);
    expect(setValueSpy).toHaveLastReturnedWith({ type: "value", value: 0 });
    instance.unmount();
    startSpy.mockRestore();
    setValueSpy.mockRestore();
});
it("Fires animation on creation", function () {
    var keyframes = {
        test: [
            { time: 0, style: { color: "red", opacity: 0 } },
            { time: 1, style: { color: "blue", opacity: 1 } }
        ]
    };
    var animation = {
        delay: 0,
        duration: 1000,
        iterations: 1,
        name: "test",
        timingFunction: "linear"
    };
    var animationStyle;
    var Test = function () {
        var _a;
        _a = useAnimation_1["default"](keyframes, animation, null), animationStyle = _a[1];
        return null;
    };
    var instance = react_test_renderer_1.create(react_1["default"].createElement(Test));
    expect(Object.keys(animationStyle)).toEqual(["color", "opacity"]);
    instance.unmount();
});
it("Handles looping", function () {
    var keyframes = {
        test: [
            { time: 0, style: { color: "red" } },
            { time: 1, style: { color: "blue" } }
        ]
    };
    var animation = {
        delay: 0,
        duration: 1000,
        iterations: 3,
        name: "test",
        timingFunction: "linear"
    };
    var startSpy = jest.spyOn(react_native_1.AnimatedNode.prototype, "start");
    var Test = function () {
        useAnimation_1["default"](keyframes, animation, null);
        return null;
    };
    var instance = react_test_renderer_1.create(react_1["default"].createElement(Test));
    expect(startSpy).toHaveReturnedWith({
        type: "parallel",
        value: [
            {
                type: "loop",
                value: {
                    type: "sequence",
                    value: [
                        {
                            type: "timing",
                            value: { type: "value", value: 0 },
                            options: {
                                delay: 0,
                                duration: 1000,
                                easing: "linear",
                                toValue: 1
                            }
                        },
                        {
                            type: "timing",
                            value: { type: "value", value: 0 },
                            options: { duration: 0, toValue: 0 }
                        }
                    ]
                },
                options: { iterations: 3 }
            }
        ]
    });
    instance.unmount();
    startSpy.mockRestore();
});
it("Handles no animation", function () {
    var keyframes = {};
    var animation = {
        delay: 0,
        duration: 1000,
        iterations: 3,
        name: null,
        timingFunction: "linear"
    };
    var startSpy = jest.spyOn(react_native_1.AnimatedNode.prototype, "start");
    var Test = function () {
        useAnimation_1["default"](keyframes, animation, null);
        return null;
    };
    var instance = react_test_renderer_1.create(react_1["default"].createElement(Test));
    expect(startSpy).not.toHaveBeenCalled();
    instance.unmount();
    startSpy.mockRestore();
});
it("Handles missing start frame", function () {
    var keyframes = {
        test: [{ time: 1, style: { color: "blue" } }]
    };
    var animation = {
        delay: 0,
        duration: 1000,
        iterations: 3,
        name: "test",
        timingFunction: "linear"
    };
    var animationStyle;
    var Test = function () {
        var _a;
        _a = useAnimation_1["default"](keyframes, animation, {
            color: "red"
        }), animationStyle = _a[1];
        return null;
    };
    var instance = react_test_renderer_1.create(react_1["default"].createElement(Test));
    expect(animationStyle).toEqual({
        color: {
            type: "interpolate",
            value: 0,
            options: {
                inputRange: [0, 1],
                outputRange: ["red", "blue"]
            }
        }
    });
    instance.unmount();
});
it("Handles missing end frame", function () {
    var keyframes = {
        test: [{ time: 0, style: { color: "blue" } }]
    };
    var animation = {
        delay: 0,
        duration: 1000,
        iterations: 3,
        name: "test",
        timingFunction: "linear"
    };
    var animationStyle;
    var Test = function () {
        var _a;
        _a = useAnimation_1["default"](keyframes, animation, {
            color: "red"
        }), animationStyle = _a[1];
        return null;
    };
    var instance = react_test_renderer_1.create(react_1["default"].createElement(Test));
    expect(animationStyle).toEqual({
        color: {
            type: "interpolate",
            value: 0,
            options: {
                inputRange: [0, 1],
                outputRange: ["blue", "red"]
            }
        }
    });
    instance.unmount();
});
