"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var react_1 = __importDefault(require("react"));
var react_test_renderer_1 = require("react-test-renderer");
var useTransition_1 = __importDefault(require("../useTransition"));
it("Transitions when changing styles", function () {
    var transition = [
        {
            property: "color",
            delay: 0,
            duration: 1000,
            timingFunction: "linear"
        }
    ];
    var transitionStyle;
    var Test = function (_a) {
        var _b;
        var styles = _a.styles;
        _b = useTransition_1["default"](transition, styles), transitionStyle = _b[1];
        return null;
    };
    var instance = react_test_renderer_1.create(react_1["default"].createElement(Test, { styles: { color: "red" } }));
    expect(transitionStyle).toEqual({
        color: {
            options: { inputRange: [0, 1], outputRange: ["red", "red"] },
            type: "interpolate",
            value: 0
        }
    });
    instance.update(react_1["default"].createElement(Test, { styles: { color: "blue" } }));
    expect(transitionStyle).toEqual({
        color: {
            options: { inputRange: [0, 1], outputRange: ["red", "blue"] },
            type: "interpolate",
            value: 0
        }
    });
    instance.unmount();
});
it("Does not transition when style has no value", function () {
    var transition = [
        {
            property: "color",
            delay: 0,
            duration: 1000,
            timingFunction: "linear"
        }
    ];
    var transitionStyle;
    var Test = function (_a) {
        var _b;
        var styles = _a.styles;
        _b = useTransition_1["default"](transition, styles), transitionStyle = _b[1];
        return null;
    };
    var instance = react_test_renderer_1.create(react_1["default"].createElement(Test, { styles: {} }));
    expect(transitionStyle).toEqual({});
    instance.unmount();
});
it("Handles going from no value to a new value", function () {
    var transition = [
        {
            property: "color",
            delay: 0,
            duration: 1000,
            timingFunction: "linear"
        }
    ];
    var transitionStyle;
    var Test = function (_a) {
        var _b;
        var styles = _a.styles;
        _b = useTransition_1["default"](transition, styles), transitionStyle = _b[1];
        return null;
    };
    var instance = react_test_renderer_1.create(react_1["default"].createElement(Test, { styles: {} }));
    expect(transitionStyle).toEqual({});
    instance.update(react_1["default"].createElement(Test, { styles: { color: "red" } }));
    expect(transitionStyle).toEqual({});
    instance.update(react_1["default"].createElement(Test, { styles: { color: "blue" } }));
    expect(transitionStyle).toEqual({
        color: {
            options: { inputRange: [0, 1], outputRange: ["red", "blue"] },
            type: "interpolate",
            value: 0
        }
    });
    instance.unmount();
});
it("Handles adding more transitioned values", function () {
    var transition1 = [
        {
            property: "color",
            delay: 0,
            duration: 1000,
            timingFunction: "linear"
        }
    ];
    var transition2 = __spreadArrays(transition1, [
        {
            property: "opacity",
            delay: 0,
            duration: 1000,
            timingFunction: "linear"
        }
    ]);
    var transitionStyle;
    var Test = function (_a) {
        var _b;
        var styles = _a.styles, transition = _a.transition;
        _b = useTransition_1["default"](transition, styles), transitionStyle = _b[1];
        return null;
    };
    var instance = react_test_renderer_1.create(react_1["default"].createElement(Test, {
        styles: { color: "red", opacity: 0 },
        transition: transition1
    }));
    expect(transitionStyle).toEqual({
        color: {
            options: { inputRange: [0, 1], outputRange: ["red", "red"] },
            type: "interpolate",
            value: 0
        }
    });
    instance.update(react_1["default"].createElement(Test, {
        styles: { color: "blue", opacity: 0.5 },
        transition: transition1
    }));
    expect(transitionStyle).toEqual({
        color: {
            options: { inputRange: [0, 1], outputRange: ["red", "blue"] },
            type: "interpolate",
            value: 0
        }
    });
    instance.update(react_1["default"].createElement(Test, {
        styles: { color: "green", opacity: 1 },
        transition: transition2
    }));
    expect(transitionStyle).toEqual({
        color: {
            options: { inputRange: [0, 1], outputRange: ["blue", "green"] },
            type: "interpolate",
            value: 0
        },
        opacity: { type: "value", value: 0.5 }
    });
    instance.unmount();
});
it("Handles no more transitions", function () {
    var transition = [];
    var style;
    var Test = function (_a) {
        var styles = _a.styles;
        style = useTransition_1["default"](transition, styles);
        return null;
    };
    var instance = react_test_renderer_1.create(react_1["default"].createElement(Test, { styles: { color: "red" } }));
    expect(style).toEqual({ color: "red" });
    instance.unmount();
});
