"use strict";
exports.__esModule = true;
var react_native_1 = require("react-native");
exports.interpolateValue = function (inputRange, outputRange, animation, interpolateNumbers) {
    if (interpolateNumbers === void 0) { interpolateNumbers = false; }
    var firstValue = outputRange[0];
    if (interpolateNumbers && typeof firstValue === "number") {
        return animation;
    }
    else if (!Array.isArray(firstValue)) {
        return animation.interpolate({ inputRange: inputRange, outputRange: outputRange });
    }
    // transforms
    if (process.env.NODE_ENV !== "production") {
        var currentProperties_1 = String(firstValue.map(Object.keys));
        // Not the *best* practise here...
        var transformsAreConsistent = outputRange.every(function (range) {
            var rangeProperties = String(range.map(Object.keys));
            return currentProperties_1 === rangeProperties;
        });
        if (!transformsAreConsistent) {
            // eslint-disable-next-line no-console
            console.error("Expected transforms to have same shape between transitions");
        }
    }
    return firstValue.map(function (transform, index) {
        var _a;
        var transformProperty = Object.keys(transform)[0];
        var innerOutputRange = outputRange.map(function (range) {
            var rangeValue = range[index];
            return rangeValue != null ? rangeValue[transformProperty] : null;
        });
        // We *have* to interpolate even numeric values, as we will always animate between 0--1
        var interpolation = animation.interpolate({
            inputRange: inputRange,
            outputRange: innerOutputRange
        });
        return _a = {}, _a[transformProperty] = interpolation, _a;
    });
};
exports.easingFunctions = {
    linear: react_native_1.Easing.linear,
    ease: react_native_1.Easing.ease,
    "ease-in": react_native_1.Easing.bezier(0.42, 0, 1.0, 1.0),
    "ease-out": react_native_1.Easing.bezier(0, 0, 0.58, 1.0),
    "ease-in-out": react_native_1.Easing.bezier(0.42, 0, 0.58, 1.0)
};
