"use strict";
exports.__esModule = true;
// Two levels of nesting
var calcFnRe = /calc\(((?:[^(]|\((?:[^(]|\([^(]+\))+\))+)\)/g;
var bracketsRe = /\(([^)]+)\)/g;
var addSubtractRe = /([^+-]+)([+-])(.*)/;
var multiplyDivideRe = /([^*/]+)([*/])(.*)/;
var unitRe = /([\d.]+)(px|)/;
var resolveValue = function (value) {
    var match = value.match(unitRe);
    if (match === null)
        return null;
    return { value: Number(match[1]), unit: match[2] };
};
var resolveMultiplyDivide = function (value) {
    var match = value.match(multiplyDivideRe);
    if (match === null)
        return resolveValue(value);
    var lhs = resolveValue(match[1]);
    if (lhs === null)
        return null;
    var rhs = resolveMultiplyDivide(match[3]);
    if (rhs === null)
        return null;
    if (match[2] === "*") {
        if (lhs.unit.length === 0) {
            return { value: lhs.value * rhs.value, unit: rhs.unit };
        }
        else if (rhs.unit.length === 0) {
            return { value: lhs.value * rhs.value, unit: lhs.unit };
        }
    }
    else if (match[2] === "/") {
        if (rhs.unit.length === 0) {
            return { value: lhs.value / rhs.value, unit: lhs.unit };
        }
    }
    return null;
};
var resolveAddSubtract = function (value) {
    var match = value.match(addSubtractRe);
    if (match === null)
        return resolveMultiplyDivide(value);
    var lhs = resolveMultiplyDivide(match[1]);
    if (lhs === null)
        return null;
    var rhs = resolveAddSubtract(match[3]);
    if (rhs === null)
        return null;
    if (lhs.unit !== rhs.unit)
        return null;
    return {
        value: match[2] === "+" ? lhs.value + rhs.value : lhs.value - rhs.value,
        unit: lhs.unit
    };
};
var resolveBrackets = function (value) {
    var out = value.replace(bracketsRe, function (_, inner) { return resolveBrackets(inner); });
    var node = resolveAddSubtract(out);
    if (node !== null) {
        return "" + node.value + node.unit;
    }
    else {
        throw new Error("Failed to parse calc");
    }
};
exports["default"] = (function (inputValue) {
    var value = inputValue;
    var didReplace;
    do {
        didReplace = false;
        value = value.replace(calcFnRe, function (_, rest) {
            didReplace = true;
            return resolveBrackets(rest);
        });
    } while (didReplace);
    return value;
});
