"use strict";
exports.__esModule = true;
var animationShorthandUtil_1 = require("./animationShorthandUtil");
var iterationsRegExp = /^(\d+|infinite)$/i;
var getIterationCount = function (iteration) {
    return /infinite/i.test(iteration) ? -1 : parseInt(iteration, 10);
};
var defaultValue = function () { return ({
    delay: 0,
    duration: 0,
    iterations: 1,
    name: null,
    timingFunction: "ease"
}); };
var TIMING_FUNCTION = 1 << 0;
var DURATION = 1 << 1;
var DELAY = 1 << 2;
var ITERATION_COUNT = 1 << 3;
var NAME = 1 << 4;
var getAnimationShorthand = function (shorthandParts) {
    var accum = defaultValue();
    var set = 0;
    shorthandParts.forEach(function (part) {
        if (!(set & TIMING_FUNCTION) && animationShorthandUtil_1.easingRegExp.test(part)) {
            accum.timingFunction = part;
            set &= TIMING_FUNCTION;
        }
        else if (!(set & DURATION) && animationShorthandUtil_1.durationRegExp.test(part)) {
            accum.duration = animationShorthandUtil_1.getDurationInMs(part);
            set &= DURATION;
        }
        else if (!(set & DELAY) && animationShorthandUtil_1.durationRegExp.test(part)) {
            accum.delay = animationShorthandUtil_1.getDurationInMs(part);
            set &= DURATION;
        }
        else if (!(set & ITERATION_COUNT) && iterationsRegExp.test(part)) {
            accum.iterations = getIterationCount(part);
            set &= ITERATION_COUNT;
        }
        else if (!(set & NAME)) {
            accum.name = part;
            set &= NAME;
        }
        else {
            throw new Error("Failed to parse shorthand");
        }
    });
    return accum;
};
exports["default"] = (function (styles) {
    var accum = defaultValue();
    styles.forEach(function (style) {
        if (style == null)
            return;
        if (style._ != null) {
            accum = getAnimationShorthand(style._.trim().split(/\s+/));
        }
        if (style.timingFunction != null) {
            accum.timingFunction = style.timingFunction;
        }
        if (style.delay != null) {
            accum.delay = animationShorthandUtil_1.getDurationInMs(style.delay);
        }
        if (style.duration != null) {
            accum.duration = animationShorthandUtil_1.getDurationInMs(style.duration);
        }
        if (style.iterations != null) {
            accum.iterations = getIterationCount(style.iterations);
        }
        if (style.name != null) {
            accum.name = style.name !== "none" ? style.name : null;
        }
    });
    return accum;
});
