"use strict";
exports.__esModule = true;
var css_to_react_native_1 = require("css-to-react-native");
var animationShorthandUtil_1 = require("./animationShorthandUtil");
var DELAY = 1;
var DURATION = 1 << 1;
var TIMING_FUNCTION = 1 << 2;
var PROPERTY = 1 << 3;
var getTransitionShorthand = function (shorthandParts) {
    var accum = {
        delay: 0,
        duration: 0,
        timingFunction: "ease",
        property: null
    };
    var set = 0;
    shorthandParts.forEach(function (part) {
        if (!(set & TIMING_FUNCTION) && animationShorthandUtil_1.easingRegExp.test(part)) {
            accum.timingFunction = part;
            set &= TIMING_FUNCTION;
        }
        else if (!(set & DURATION) && animationShorthandUtil_1.durationRegExp.test(part)) {
            accum.duration = animationShorthandUtil_1.getDurationInMs(part);
            set &= DURATION;
        }
        else if (!(set & DELAY) && animationShorthandUtil_1.durationRegExp.test(part)) {
            accum.delay = animationShorthandUtil_1.getDurationInMs(part);
            set &= DELAY;
        }
        else if (!(set & PROPERTY)) {
            accum.property = css_to_react_native_1.getPropertyName(part);
            set &= PROPERTY;
        }
        else {
            throw new Error("Failed to parse shorthand");
        }
    });
    return accum;
};
var split = function (value) { return value.trim().split(/\s*,\s*/); };
exports["default"] = (function (styles) {
    var delays = [];
    var durations = [];
    var timingFunctions = [];
    var properties = [];
    styles.forEach(function (style) {
        if (style == null)
            return;
        if (style._ != null) {
            delays = [];
            durations = [];
            timingFunctions = [];
            properties = [];
            split(style._).forEach(function (shorthand) {
                var resolved = getTransitionShorthand(shorthand.trim().split(/\s+/));
                var property = resolved.property;
                if (property != null) {
                    timingFunctions.push(resolved.timingFunction);
                    delays.push(resolved.delay);
                    durations.push(resolved.duration);
                    properties.push(property);
                }
            });
        }
        if (style.timingFunction != null) {
            timingFunctions = split(style.timingFunction);
        }
        if (style.delay != null) {
            delays = split(style.delay).map(animationShorthandUtil_1.getDurationInMs);
        }
        if (style.duration != null) {
            durations = split(style.duration).map(animationShorthandUtil_1.getDurationInMs);
        }
        if (style.property != null) {
            properties =
                style.property === "none"
                    ? []
                    : split(style.property).map(css_to_react_native_1.getPropertyName);
        }
    });
    var transitions = properties.map(function (property, index) {
        /*
        Per spec, cycle through multiple values if transition-property length
        exceeds the length of the other property
        */
        var delay = delays[index % delays.length];
        var duration = durations[index % durations.length];
        var timingFunction = timingFunctions[index % timingFunctions.length];
        return { property: property, timingFunction: timingFunction, delay: delay, duration: duration };
    });
    return transitions;
});
