"use strict";
exports.__esModule = true;
var cssRegExp_1 = require("./cssRegExp");
/* eslint-disable no-prototype-builtins */
exports["default"] = (function (scope, next) {
    var out = {};
    /*
    Used to check for circular dependencies when calling resolve
    We can actully use one mutable value here, even though the function is recursive
    */
    var resolveChain = [];
    var resolve = function (key) {
        var existing = out[key];
        if (existing != null)
            return existing;
        var unresolvedValue;
        if (next.hasOwnProperty(key)) {
            var value = next[key];
            if (value === "initial") {
                unresolvedValue = null;
            }
            else if (value === "inherit" || value === "unset") {
                unresolvedValue = scope[key];
            }
            else {
                unresolvedValue = value;
            }
        }
        else if (scope.hasOwnProperty(key)) {
            unresolvedValue = scope[key];
        }
        else {
            unresolvedValue = null;
        }
        if (unresolvedValue == null)
            return undefined;
        var chainIndex = resolveChain.indexOf(key);
        if (chainIndex !== -1) {
            var circularLoop = resolveChain
                .slice(chainIndex)
                .concat(key)
                .join(" -> ");
            throw new Error("Circular dependency found in CSS custom properties: " + circularLoop);
        }
        resolveChain.push(key);
        var missingValues = false;
        var resolvedValue = unresolvedValue.replace(cssRegExp_1.varRegExp, function (_, reference, fallback) {
            var resolved = resolve(reference);
            if (resolved != null) {
                return resolved;
            }
            else if (fallback != null) {
                return fallback;
            }
            else {
                missingValues = true;
                return "";
            }
        });
        if (!missingValues) {
            out[key] = resolvedValue;
        }
        resolveChain.pop();
        return resolvedValue;
    };
    Object.keys(scope).forEach(resolve);
    Object.keys(next).forEach(resolve);
    return out;
});
