"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
exports.__esModule = true;
var react_1 = require("react");
var react_native_1 = require("react-native");
var animationUtil_1 = require("./animationUtil");
var noAnimations = {
    animations: null,
    animationValues: null,
    delay: 0,
    duration: 0,
    iterations: 1,
    name: null,
    timingFunction: "ease"
};
var getAnimationState = function (keyframes, animation, style) {
    if (animation == null)
        return noAnimations;
    var delay = animation.delay, duration = animation.duration, iterations = animation.iterations, name = animation.name, timingFunction = animation.timingFunction;
    var currentStyles = react_native_1.StyleSheet.flatten(style);
    var animationSequence = name != null ? keyframes[name] : null;
    if (animationSequence == null)
        return noAnimations;
    var animatedProperties = Object.keys(Object.assign.apply(Object, __spreadArrays([{}], animationSequence.map(function (frame) { return frame.style; }))));
    var animationValues = {};
    var animations = {};
    animatedProperties.forEach(function (animationProperty) {
        animationValues[animationProperty] = new react_native_1.Animated.Value(0);
        var currentValue = currentStyles[animationProperty];
        var keyframes = animationSequence
            .filter(function (frame) { return animationProperty in frame.style; })
            .map(function (_a) {
            var time = _a.time, style = _a.style;
            return ({ time: time, value: style[animationProperty] });
        });
        // Fixes missing start/end values
        keyframes = [].concat(keyframes[0].time > 0 ? [{ time: 0, value: currentValue }] : [], keyframes, keyframes[keyframes.length - 1].time < 1
            ? [{ time: 1, value: currentValue }]
            : []);
        var inputRange = keyframes.map(function (frame) { return frame.time; });
        var outputRange = keyframes.map(function (frame) { return frame.value; });
        var animation = animationValues[animationProperty];
        animations[animationProperty] = animationUtil_1.interpolateValue(inputRange, outputRange, animation);
    }, {});
    return {
        animations: animations,
        animationValues: animationValues,
        delay: delay,
        duration: duration,
        iterations: iterations,
        name: name,
        timingFunction: timingFunction
    };
};
var animate = function (_a) {
    var delay = _a.delay, duration = _a.duration, iterations = _a.iterations, timingFunction = _a.timingFunction, animationValuesObject = _a.animationValues;
    if (animationValuesObject == null)
        return;
    var animationValues = Object.values(animationValuesObject);
    animationValues.forEach(function (animation) { return animation.setValue(0); });
    var timings = animationValues.map(function (animation) {
        var config = {
            toValue: 1,
            duration: duration,
            delay: delay,
            easing: typeof timingFunction === "string"
                ? animationUtil_1.easingFunctions[timingFunction]
                : timingFunction
        };
        var res = react_native_1.Animated.timing(animation, config);
        if (iterations !== 1) {
            res = react_native_1.Animated.sequence([
                res,
                // Reset animation
                react_native_1.Animated.timing(animation, { toValue: 0, duration: 0 })
            ]);
            res = react_native_1.Animated.loop(res, { iterations: iterations });
        }
        return res;
    });
    react_native_1.Animated.parallel(timings).start();
    /*
    ({ finished }) => {
      // FIXME: This doesn't seem to clear the animation
      if (finished) {
        setState({ animations: null, animationValues: null });
      }
    }
    */
};
exports["default"] = (function (keyframes, animation, style) {
    var state = getAnimationState(keyframes, animation, style);
    var animations = state.animations, name = state.name;
    react_1.useLayoutEffect(function () {
        animate(state);
    }, [name]);
    var nextStyle = animations == null ? style : [style, animations];
    return nextStyle;
});
