"use strict";
exports.__esModule = true;
var react_1 = require("react");
var react_native_1 = require("react-native");
var animationUtil_1 = require("./animationUtil");
var getInitialValue = function (targetValue) {
    return typeof targetValue === "number" ? targetValue : 0;
};
var useStyleGroup = function (transition, inputStyleUnflattened) {
    var inputStyle = react_native_1.StyleSheet.flatten(inputStyleUnflattened);
    var _a = react_1.useState(function () { return ({
        style: inputStyle,
        previousStyle: inputStyle
    }); }), _b = _a[0], style = _b.style, previousStyle = _b.previousStyle, setStyleGroup = _a[1];
    var styleChanged = transition.some(function (_a) {
        var property = _a.property;
        return inputStyle[property] !== style[property];
    });
    if (styleChanged) {
        setStyleGroup({ style: inputStyle, previousStyle: style });
    }
    return { style: style, previousStyle: previousStyle };
};
var useAnimationValues = function (transition, style) {
    var _a = react_1.useState(function () {
        var values = {};
        transition.forEach(function (_a) {
            var property = _a.property;
            var initialValue = getInitialValue(style[property]);
            values[property] = new react_native_1.Animated.Value(initialValue);
        });
        return values;
    }), animationValues = _a[0], setAnimationValues = _a[1];
    var needsNewAnimationValues = Object.keys(animationValues).length !== transition.length ||
        transition.some(function (_a) {
            var property = _a.property;
            return animationValues[property] == null;
        });
    if (needsNewAnimationValues) {
        var values_1 = {};
        transition.forEach(function (_a) {
            var property = _a.property;
            var existing = animationValues[property];
            if (existing != null) {
                values_1[property] = existing;
            }
            else {
                var initialValue = getInitialValue(style[property]);
                values_1[property] = new react_native_1.Animated.Value(initialValue);
            }
        });
        setAnimationValues(values_1);
    }
    return animationValues;
};
var animate = function (transition, style, previousStyle, animationValues) {
    // Don't run on initial mount
    if (style === previousStyle)
        return;
    var animations = transition.map(function (_a) {
        var property = _a.property, delay = _a.delay, duration = _a.duration, timingFunction = _a.timingFunction;
        var animation = animationValues[property];
        var targetValue = style[property];
        var needsInterpolation = typeof targetValue !== "number";
        var toValue = !needsInterpolation ? targetValue : 1;
        if (needsInterpolation)
            animation.setValue(0);
        return react_native_1.Animated.timing(animation, {
            toValue: toValue,
            duration: duration,
            delay: delay,
            easing: animationUtil_1.easingFunctions[timingFunction]
        });
    });
    react_native_1.Animated.parallel(animations).start();
};
exports["default"] = (function (transition, inputStyleUnflattened) {
    var _a = useStyleGroup(transition, inputStyleUnflattened), style = _a.style, previousStyle = _a.previousStyle;
    var animationValues = useAnimationValues(transition, style);
    react_1.useLayoutEffect(function () {
        animate(transition, style, previousStyle, animationValues);
    }, [style, previousStyle]);
    var nextStyle = react_1.useMemo(function () {
        var animationNames = Object.keys(animationValues);
        if (animationNames.length === 0)
            return inputStyleUnflattened;
        var transitionStyle = {};
        animationNames.forEach(function (animationName) {
            var previousValue = previousStyle[animationName];
            var nextValue = style[animationName];
            if (previousValue != null && nextValue != null) {
                transitionStyle[animationName] = animationUtil_1.interpolateValue([0, 1], [previousValue, nextValue], animationValues[animationName], true /* interpolate numbers */);
            }
        });
        return [style, transitionStyle];
    }, [animationValues, style, previousStyle]);
    return nextStyle;
});
